/*********************************************************************
 * File automatically generated by rebuild_wrappers_32.py (v0.0.2.2) *
 *********************************************************************/
#ifndef __WRAPPER32_H_
#define __WRAPPER32_H_
#include <stdint.h>
#include <string.h>

typedef struct x64emu_s x64emu_t;

// the generic wrapper pointer functions
typedef void (*wrapper_t)(x64emu_t* emu, uintptr_t fnc);

// list of defined wrappers
// E = current x64emu struct
// v = void
// C = unsigned byte c = char
// W = unsigned short w = short
// u = uint32, i = int32
// U = uint64, I = int64
// L = unsigned long, l = signed long (long is an int with the size of a pointer)
// p = pointer
// h = hash (32<->64bits)
// H = hash (32<->64bits) that will be deleted from hashmaps
// a = locale
// A = locale that will be deleted from hashmaps
// f = float, d = double, D = long double, K = fake long double
// V = vaargs, s = address on the stack (doesn't move forward the pointer)
// O = libc O_ flags bitfield
// o = stdout
// S = _IO_2_1_stdXXX_ pointer (or FILE*)
// 2 = struct of 2 uint
// N = ... automatically sending 1 arg
// M = ... automatically sending 2 args
// P = Vulkan struct pointer
// r..._ = pointer to read-only structure
// B..._ = pointer to write-only structure
// b..._ = pointer to read-write structure
// t = char* as a return value (copies to a lower address if the return address is too high)
// X = Display*

void vEv_32(x64emu_t *emu, uintptr_t fnc);
void vFv_32(x64emu_t *emu, uintptr_t fnc);
void vFc_32(x64emu_t *emu, uintptr_t fnc);
void vFw_32(x64emu_t *emu, uintptr_t fnc);
void vEi_32(x64emu_t *emu, uintptr_t fnc);
void vFi_32(x64emu_t *emu, uintptr_t fnc);
void vFC_32(x64emu_t *emu, uintptr_t fnc);
void vFW_32(x64emu_t *emu, uintptr_t fnc);
void vEu_32(x64emu_t *emu, uintptr_t fnc);
void vFu_32(x64emu_t *emu, uintptr_t fnc);
void vFU_32(x64emu_t *emu, uintptr_t fnc);
void vFf_32(x64emu_t *emu, uintptr_t fnc);
void vFd_32(x64emu_t *emu, uintptr_t fnc);
void vEl_32(x64emu_t *emu, uintptr_t fnc);
void vFl_32(x64emu_t *emu, uintptr_t fnc);
void vEp_32(x64emu_t *emu, uintptr_t fnc);
void vFp_32(x64emu_t *emu, uintptr_t fnc);
void vEA_32(x64emu_t *emu, uintptr_t fnc);
void vES_32(x64emu_t *emu, uintptr_t fnc);
void vFS_32(x64emu_t *emu, uintptr_t fnc);
void vFX_32(x64emu_t *emu, uintptr_t fnc);
void vFn_32(x64emu_t *emu, uintptr_t fnc);
void cFc_32(x64emu_t *emu, uintptr_t fnc);
void cFi_32(x64emu_t *emu, uintptr_t fnc);
void cFu_32(x64emu_t *emu, uintptr_t fnc);
void cFp_32(x64emu_t *emu, uintptr_t fnc);
void wFp_32(x64emu_t *emu, uintptr_t fnc);
void iEv_32(x64emu_t *emu, uintptr_t fnc);
void iFv_32(x64emu_t *emu, uintptr_t fnc);
void iEi_32(x64emu_t *emu, uintptr_t fnc);
void iFi_32(x64emu_t *emu, uintptr_t fnc);
void iEI_32(x64emu_t *emu, uintptr_t fnc);
void iEu_32(x64emu_t *emu, uintptr_t fnc);
void iFu_32(x64emu_t *emu, uintptr_t fnc);
void iFU_32(x64emu_t *emu, uintptr_t fnc);
void iEf_32(x64emu_t *emu, uintptr_t fnc);
void iEd_32(x64emu_t *emu, uintptr_t fnc);
void iEl_32(x64emu_t *emu, uintptr_t fnc);
void iEL_32(x64emu_t *emu, uintptr_t fnc);
void iFL_32(x64emu_t *emu, uintptr_t fnc);
void iEp_32(x64emu_t *emu, uintptr_t fnc);
void iFp_32(x64emu_t *emu, uintptr_t fnc);
void iEh_32(x64emu_t *emu, uintptr_t fnc);
void iES_32(x64emu_t *emu, uintptr_t fnc);
void iFX_32(x64emu_t *emu, uintptr_t fnc);
void iFn_32(x64emu_t *emu, uintptr_t fnc);
void IFi_32(x64emu_t *emu, uintptr_t fnc);
void IEf_32(x64emu_t *emu, uintptr_t fnc);
void IEd_32(x64emu_t *emu, uintptr_t fnc);
void IEp_32(x64emu_t *emu, uintptr_t fnc);
void IFp_32(x64emu_t *emu, uintptr_t fnc);
void IES_32(x64emu_t *emu, uintptr_t fnc);
void CFv_32(x64emu_t *emu, uintptr_t fnc);
void CFi_32(x64emu_t *emu, uintptr_t fnc);
void CFu_32(x64emu_t *emu, uintptr_t fnc);
void CFU_32(x64emu_t *emu, uintptr_t fnc);
void CFl_32(x64emu_t *emu, uintptr_t fnc);
void CFp_32(x64emu_t *emu, uintptr_t fnc);
void WFi_32(x64emu_t *emu, uintptr_t fnc);
void WEW_32(x64emu_t *emu, uintptr_t fnc);
void WFu_32(x64emu_t *emu, uintptr_t fnc);
void WFp_32(x64emu_t *emu, uintptr_t fnc);
void uEv_32(x64emu_t *emu, uintptr_t fnc);
void uFv_32(x64emu_t *emu, uintptr_t fnc);
void uEi_32(x64emu_t *emu, uintptr_t fnc);
void uFi_32(x64emu_t *emu, uintptr_t fnc);
void uEu_32(x64emu_t *emu, uintptr_t fnc);
void uFu_32(x64emu_t *emu, uintptr_t fnc);
void uEU_32(x64emu_t *emu, uintptr_t fnc);
void uFl_32(x64emu_t *emu, uintptr_t fnc);
void uEp_32(x64emu_t *emu, uintptr_t fnc);
void uFp_32(x64emu_t *emu, uintptr_t fnc);
void uES_32(x64emu_t *emu, uintptr_t fnc);
void uFX_32(x64emu_t *emu, uintptr_t fnc);
void uFn_32(x64emu_t *emu, uintptr_t fnc);
void UFv_32(x64emu_t *emu, uintptr_t fnc);
void UFi_32(x64emu_t *emu, uintptr_t fnc);
void UFu_32(x64emu_t *emu, uintptr_t fnc);
void UEp_32(x64emu_t *emu, uintptr_t fnc);
void UFp_32(x64emu_t *emu, uintptr_t fnc);
void UEs_32(x64emu_t *emu, uintptr_t fnc);
void fFi_32(x64emu_t *emu, uintptr_t fnc);
void fEf_32(x64emu_t *emu, uintptr_t fnc);
void fFf_32(x64emu_t *emu, uintptr_t fnc);
void fEp_32(x64emu_t *emu, uintptr_t fnc);
void dEv_32(x64emu_t *emu, uintptr_t fnc);
void dFi_32(x64emu_t *emu, uintptr_t fnc);
void dEd_32(x64emu_t *emu, uintptr_t fnc);
void dFd_32(x64emu_t *emu, uintptr_t fnc);
void dEp_32(x64emu_t *emu, uintptr_t fnc);
void dFp_32(x64emu_t *emu, uintptr_t fnc);
void lEv_32(x64emu_t *emu, uintptr_t fnc);
void lFu_32(x64emu_t *emu, uintptr_t fnc);
void lEl_32(x64emu_t *emu, uintptr_t fnc);
void lFl_32(x64emu_t *emu, uintptr_t fnc);
void lEp_32(x64emu_t *emu, uintptr_t fnc);
void lFp_32(x64emu_t *emu, uintptr_t fnc);
void lES_32(x64emu_t *emu, uintptr_t fnc);
void lFX_32(x64emu_t *emu, uintptr_t fnc);
void LEv_32(x64emu_t *emu, uintptr_t fnc);
void LFv_32(x64emu_t *emu, uintptr_t fnc);
void LFi_32(x64emu_t *emu, uintptr_t fnc);
void LFu_32(x64emu_t *emu, uintptr_t fnc);
void LEL_32(x64emu_t *emu, uintptr_t fnc);
void LEp_32(x64emu_t *emu, uintptr_t fnc);
void LFp_32(x64emu_t *emu, uintptr_t fnc);
void LFX_32(x64emu_t *emu, uintptr_t fnc);
void pEv_32(x64emu_t *emu, uintptr_t fnc);
void pFv_32(x64emu_t *emu, uintptr_t fnc);
void pEi_32(x64emu_t *emu, uintptr_t fnc);
void pFi_32(x64emu_t *emu, uintptr_t fnc);
void pFI_32(x64emu_t *emu, uintptr_t fnc);
void pFW_32(x64emu_t *emu, uintptr_t fnc);
void pFu_32(x64emu_t *emu, uintptr_t fnc);
void pEu_32(x64emu_t *emu, uintptr_t fnc);
void pFU_32(x64emu_t *emu, uintptr_t fnc);
void pEl_32(x64emu_t *emu, uintptr_t fnc);
void pFl_32(x64emu_t *emu, uintptr_t fnc);
void pEL_32(x64emu_t *emu, uintptr_t fnc);
void pFL_32(x64emu_t *emu, uintptr_t fnc);
void pEp_32(x64emu_t *emu, uintptr_t fnc);
void pFp_32(x64emu_t *emu, uintptr_t fnc);
void pFX_32(x64emu_t *emu, uintptr_t fnc);
void pFn_32(x64emu_t *emu, uintptr_t fnc);
void hEv_32(x64emu_t *emu, uintptr_t fnc);
void hFv_32(x64emu_t *emu, uintptr_t fnc);
void aEa_32(x64emu_t *emu, uintptr_t fnc);
void tEv_32(x64emu_t *emu, uintptr_t fnc);
void tEi_32(x64emu_t *emu, uintptr_t fnc);
void tEu_32(x64emu_t *emu, uintptr_t fnc);
void tEp_32(x64emu_t *emu, uintptr_t fnc);
void tFp_32(x64emu_t *emu, uintptr_t fnc);
void XFv_32(x64emu_t *emu, uintptr_t fnc);
void XFp_32(x64emu_t *emu, uintptr_t fnc);
void vFbp__32(x64emu_t *emu, uintptr_t fnc);
void iFbp__32(x64emu_t *emu, uintptr_t fnc);
void iFBp__32(x64emu_t *emu, uintptr_t fnc);
void uFbp__32(x64emu_t *emu, uintptr_t fnc);
void LEBL__32(x64emu_t *emu, uintptr_t fnc);
void pErl__32(x64emu_t *emu, uintptr_t fnc);
void pFbp__32(x64emu_t *emu, uintptr_t fnc);
void iFbpu__32(x64emu_t *emu, uintptr_t fnc);
void IFbpu__32(x64emu_t *emu, uintptr_t fnc);
void uFbup__32(x64emu_t *emu, uintptr_t fnc);
void lFrll__32(x64emu_t *emu, uintptr_t fnc);
void vFbpii__32(x64emu_t *emu, uintptr_t fnc);
void vFbLdd__32(x64emu_t *emu, uintptr_t fnc);
void vFbupi__32(x64emu_t *emu, uintptr_t fnc);
void uFbuUp__32(x64emu_t *emu, uintptr_t fnc);
void iErLWww__32(x64emu_t *emu, uintptr_t fnc);
void iEBllll__32(x64emu_t *emu, uintptr_t fnc);
void iFbppuii__32(x64emu_t *emu, uintptr_t fnc);
void uFbppuii__32(x64emu_t *emu, uintptr_t fnc);
void pFbppuii__32(x64emu_t *emu, uintptr_t fnc);
void uFbuuppuu__32(x64emu_t *emu, uintptr_t fnc);
void vFbuuipWCCp__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void uFbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void vFbWWpWpWpWp__32(x64emu_t *emu, uintptr_t fnc);
void LEbiiiiiiiiilt__32(x64emu_t *emu, uintptr_t fnc);
void pEriiiiiiiiilt__32(x64emu_t *emu, uintptr_t fnc);
void iFbppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void uFbppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void pFbppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void vEEv_32(x64emu_t *emu, uintptr_t fnc);
void vFEv_32(x64emu_t *emu, uintptr_t fnc);
void vFEi_32(x64emu_t *emu, uintptr_t fnc);
void vEEp_32(x64emu_t *emu, uintptr_t fnc);
void vFEp_32(x64emu_t *emu, uintptr_t fnc);
void vFEX_32(x64emu_t *emu, uintptr_t fnc);
void vFcc_32(x64emu_t *emu, uintptr_t fnc);
void vFww_32(x64emu_t *emu, uintptr_t fnc);
void vFii_32(x64emu_t *emu, uintptr_t fnc);
void vFiI_32(x64emu_t *emu, uintptr_t fnc);
void vFiW_32(x64emu_t *emu, uintptr_t fnc);
void vFiu_32(x64emu_t *emu, uintptr_t fnc);
void vFiU_32(x64emu_t *emu, uintptr_t fnc);
void vFif_32(x64emu_t *emu, uintptr_t fnc);
void vFid_32(x64emu_t *emu, uintptr_t fnc);
void vFip_32(x64emu_t *emu, uintptr_t fnc);
void vFWW_32(x64emu_t *emu, uintptr_t fnc);
void vFWu_32(x64emu_t *emu, uintptr_t fnc);
void vFuc_32(x64emu_t *emu, uintptr_t fnc);
void vFuw_32(x64emu_t *emu, uintptr_t fnc);
void vFui_32(x64emu_t *emu, uintptr_t fnc);
void vFuI_32(x64emu_t *emu, uintptr_t fnc);
void vFuC_32(x64emu_t *emu, uintptr_t fnc);
void vFuW_32(x64emu_t *emu, uintptr_t fnc);
void vFuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuf_32(x64emu_t *emu, uintptr_t fnc);
void vFud_32(x64emu_t *emu, uintptr_t fnc);
void vFul_32(x64emu_t *emu, uintptr_t fnc);
void vFup_32(x64emu_t *emu, uintptr_t fnc);
void vFUu_32(x64emu_t *emu, uintptr_t fnc);
void vFfC_32(x64emu_t *emu, uintptr_t fnc);
void vFff_32(x64emu_t *emu, uintptr_t fnc);
void vFdd_32(x64emu_t *emu, uintptr_t fnc);
void vFlu_32(x64emu_t *emu, uintptr_t fnc);
void vFlp_32(x64emu_t *emu, uintptr_t fnc);
void vFLp_32(x64emu_t *emu, uintptr_t fnc);
void vEpi_32(x64emu_t *emu, uintptr_t fnc);
void vFpi_32(x64emu_t *emu, uintptr_t fnc);
void vFpC_32(x64emu_t *emu, uintptr_t fnc);
void vFpu_32(x64emu_t *emu, uintptr_t fnc);
void vFpd_32(x64emu_t *emu, uintptr_t fnc);
void vFpl_32(x64emu_t *emu, uintptr_t fnc);
void vEpL_32(x64emu_t *emu, uintptr_t fnc);
void vFpL_32(x64emu_t *emu, uintptr_t fnc);
void vEpp_32(x64emu_t *emu, uintptr_t fnc);
void vFpp_32(x64emu_t *emu, uintptr_t fnc);
void vFpS_32(x64emu_t *emu, uintptr_t fnc);
void vESp_32(x64emu_t *emu, uintptr_t fnc);
void vFXi_32(x64emu_t *emu, uintptr_t fnc);
void vFXu_32(x64emu_t *emu, uintptr_t fnc);
void vFXL_32(x64emu_t *emu, uintptr_t fnc);
void vFXp_32(x64emu_t *emu, uintptr_t fnc);
void vFni_32(x64emu_t *emu, uintptr_t fnc);
void vFnu_32(x64emu_t *emu, uintptr_t fnc);
void vFnU_32(x64emu_t *emu, uintptr_t fnc);
void vFnp_32(x64emu_t *emu, uintptr_t fnc);
void cFpp_32(x64emu_t *emu, uintptr_t fnc);
void wFpi_32(x64emu_t *emu, uintptr_t fnc);
void iEEv_32(x64emu_t *emu, uintptr_t fnc);
void iFEv_32(x64emu_t *emu, uintptr_t fnc);
void iEEi_32(x64emu_t *emu, uintptr_t fnc);
void iFEi_32(x64emu_t *emu, uintptr_t fnc);
void iEEL_32(x64emu_t *emu, uintptr_t fnc);
void iEEp_32(x64emu_t *emu, uintptr_t fnc);
void iFEp_32(x64emu_t *emu, uintptr_t fnc);
void iEEh_32(x64emu_t *emu, uintptr_t fnc);
void iEEO_32(x64emu_t *emu, uintptr_t fnc);
void iFEX_32(x64emu_t *emu, uintptr_t fnc);
void iEii_32(x64emu_t *emu, uintptr_t fnc);
void iFii_32(x64emu_t *emu, uintptr_t fnc);
void iEiI_32(x64emu_t *emu, uintptr_t fnc);
void iEiu_32(x64emu_t *emu, uintptr_t fnc);
void iFiu_32(x64emu_t *emu, uintptr_t fnc);
void iEil_32(x64emu_t *emu, uintptr_t fnc);
void iFiL_32(x64emu_t *emu, uintptr_t fnc);
void iEip_32(x64emu_t *emu, uintptr_t fnc);
void iFip_32(x64emu_t *emu, uintptr_t fnc);
void iEiS_32(x64emu_t *emu, uintptr_t fnc);
void iEui_32(x64emu_t *emu, uintptr_t fnc);
void iFui_32(x64emu_t *emu, uintptr_t fnc);
void iEuu_32(x64emu_t *emu, uintptr_t fnc);
void iEuL_32(x64emu_t *emu, uintptr_t fnc);
void iEup_32(x64emu_t *emu, uintptr_t fnc);
void iFup_32(x64emu_t *emu, uintptr_t fnc);
void iEua_32(x64emu_t *emu, uintptr_t fnc);
void iFpw_32(x64emu_t *emu, uintptr_t fnc);
void iEpi_32(x64emu_t *emu, uintptr_t fnc);
void iFpi_32(x64emu_t *emu, uintptr_t fnc);
void iFpI_32(x64emu_t *emu, uintptr_t fnc);
void iFpW_32(x64emu_t *emu, uintptr_t fnc);
void iEpu_32(x64emu_t *emu, uintptr_t fnc);
void iFpu_32(x64emu_t *emu, uintptr_t fnc);
void iFpU_32(x64emu_t *emu, uintptr_t fnc);
void iFpf_32(x64emu_t *emu, uintptr_t fnc);
void iFpd_32(x64emu_t *emu, uintptr_t fnc);
void iFpl_32(x64emu_t *emu, uintptr_t fnc);
void iEpL_32(x64emu_t *emu, uintptr_t fnc);
void iFpL_32(x64emu_t *emu, uintptr_t fnc);
void iEpp_32(x64emu_t *emu, uintptr_t fnc);
void iFpp_32(x64emu_t *emu, uintptr_t fnc);
void iEpV_32(x64emu_t *emu, uintptr_t fnc);
void iEpO_32(x64emu_t *emu, uintptr_t fnc);
void iEpS_32(x64emu_t *emu, uintptr_t fnc);
void iFpS_32(x64emu_t *emu, uintptr_t fnc);
void iEhi_32(x64emu_t *emu, uintptr_t fnc);
void iEhp_32(x64emu_t *emu, uintptr_t fnc);
void iEhh_32(x64emu_t *emu, uintptr_t fnc);
void iESi_32(x64emu_t *emu, uintptr_t fnc);
void iESU_32(x64emu_t *emu, uintptr_t fnc);
void iESp_32(x64emu_t *emu, uintptr_t fnc);
void iFXi_32(x64emu_t *emu, uintptr_t fnc);
void iFXW_32(x64emu_t *emu, uintptr_t fnc);
void iFXL_32(x64emu_t *emu, uintptr_t fnc);
void iFXp_32(x64emu_t *emu, uintptr_t fnc);
void IFEp_32(x64emu_t *emu, uintptr_t fnc);
void IEII_32(x64emu_t *emu, uintptr_t fnc);
void IFpI_32(x64emu_t *emu, uintptr_t fnc);
void IFpu_32(x64emu_t *emu, uintptr_t fnc);
void CFip_32(x64emu_t *emu, uintptr_t fnc);
void CFCi_32(x64emu_t *emu, uintptr_t fnc);
void CFui_32(x64emu_t *emu, uintptr_t fnc);
void CFuu_32(x64emu_t *emu, uintptr_t fnc);
void CFuU_32(x64emu_t *emu, uintptr_t fnc);
void CFpi_32(x64emu_t *emu, uintptr_t fnc);
void CFpu_32(x64emu_t *emu, uintptr_t fnc);
void CFpp_32(x64emu_t *emu, uintptr_t fnc);
void CFXL_32(x64emu_t *emu, uintptr_t fnc);
void WFEp_32(x64emu_t *emu, uintptr_t fnc);
void WFpp_32(x64emu_t *emu, uintptr_t fnc);
void uFEp_32(x64emu_t *emu, uintptr_t fnc);
void uFii_32(x64emu_t *emu, uintptr_t fnc);
void uEiS_32(x64emu_t *emu, uintptr_t fnc);
void uFWp_32(x64emu_t *emu, uintptr_t fnc);
void uFuu_32(x64emu_t *emu, uintptr_t fnc);
void uFup_32(x64emu_t *emu, uintptr_t fnc);
void uEua_32(x64emu_t *emu, uintptr_t fnc);
void uEuS_32(x64emu_t *emu, uintptr_t fnc);
void uFpi_32(x64emu_t *emu, uintptr_t fnc);
void uFpu_32(x64emu_t *emu, uintptr_t fnc);
void uFpU_32(x64emu_t *emu, uintptr_t fnc);
void uFpp_32(x64emu_t *emu, uintptr_t fnc);
void uFXL_32(x64emu_t *emu, uintptr_t fnc);
void UFEp_32(x64emu_t *emu, uintptr_t fnc);
void UEuu_32(x64emu_t *emu, uintptr_t fnc);
void UFuu_32(x64emu_t *emu, uintptr_t fnc);
void UEUU_32(x64emu_t *emu, uintptr_t fnc);
void UFpp_32(x64emu_t *emu, uintptr_t fnc);
void UEss_32(x64emu_t *emu, uintptr_t fnc);
void fEif_32(x64emu_t *emu, uintptr_t fnc);
void fFfi_32(x64emu_t *emu, uintptr_t fnc);
void fEfi_32(x64emu_t *emu, uintptr_t fnc);
void fEff_32(x64emu_t *emu, uintptr_t fnc);
void fFff_32(x64emu_t *emu, uintptr_t fnc);
void fEfD_32(x64emu_t *emu, uintptr_t fnc);
void fEfp_32(x64emu_t *emu, uintptr_t fnc);
void dEid_32(x64emu_t *emu, uintptr_t fnc);
void dFdi_32(x64emu_t *emu, uintptr_t fnc);
void dEdi_32(x64emu_t *emu, uintptr_t fnc);
void dEdd_32(x64emu_t *emu, uintptr_t fnc);
void dFdd_32(x64emu_t *emu, uintptr_t fnc);
void dEdD_32(x64emu_t *emu, uintptr_t fnc);
void dFdp_32(x64emu_t *emu, uintptr_t fnc);
void dEdp_32(x64emu_t *emu, uintptr_t fnc);
void dEll_32(x64emu_t *emu, uintptr_t fnc);
void dFpp_32(x64emu_t *emu, uintptr_t fnc);
void lEEi_32(x64emu_t *emu, uintptr_t fnc);
void lFEp_32(x64emu_t *emu, uintptr_t fnc);
void lEES_32(x64emu_t *emu, uintptr_t fnc);
void lEii_32(x64emu_t *emu, uintptr_t fnc);
void lFiL_32(x64emu_t *emu, uintptr_t fnc);
void lFui_32(x64emu_t *emu, uintptr_t fnc);
void lFll_32(x64emu_t *emu, uintptr_t fnc);
void lEpi_32(x64emu_t *emu, uintptr_t fnc);
void lFpu_32(x64emu_t *emu, uintptr_t fnc);
void lFpl_32(x64emu_t *emu, uintptr_t fnc);
void lFpL_32(x64emu_t *emu, uintptr_t fnc);
void LEEL_32(x64emu_t *emu, uintptr_t fnc);
void LFEp_32(x64emu_t *emu, uintptr_t fnc);
void LFLi_32(x64emu_t *emu, uintptr_t fnc);
void LFpc_32(x64emu_t *emu, uintptr_t fnc);
void LEpL_32(x64emu_t *emu, uintptr_t fnc);
void LEpp_32(x64emu_t *emu, uintptr_t fnc);
void LFXi_32(x64emu_t *emu, uintptr_t fnc);
void LFXu_32(x64emu_t *emu, uintptr_t fnc);
void LFXU_32(x64emu_t *emu, uintptr_t fnc);
void LFXL_32(x64emu_t *emu, uintptr_t fnc);
void LFXp_32(x64emu_t *emu, uintptr_t fnc);
void pFEv_32(x64emu_t *emu, uintptr_t fnc);
void pEEv_32(x64emu_t *emu, uintptr_t fnc);
void pFEi_32(x64emu_t *emu, uintptr_t fnc);
void pEEu_32(x64emu_t *emu, uintptr_t fnc);
void pFEp_32(x64emu_t *emu, uintptr_t fnc);
void pEEp_32(x64emu_t *emu, uintptr_t fnc);
void pEES_32(x64emu_t *emu, uintptr_t fnc);
void pFEX_32(x64emu_t *emu, uintptr_t fnc);
void pFii_32(x64emu_t *emu, uintptr_t fnc);
void pFiu_32(x64emu_t *emu, uintptr_t fnc);
void pFip_32(x64emu_t *emu, uintptr_t fnc);
void pEia_32(x64emu_t *emu, uintptr_t fnc);
void pFWu_32(x64emu_t *emu, uintptr_t fnc);
void pFuu_32(x64emu_t *emu, uintptr_t fnc);
void pEup_32(x64emu_t *emu, uintptr_t fnc);
void pFup_32(x64emu_t *emu, uintptr_t fnc);
void pELL_32(x64emu_t *emu, uintptr_t fnc);
void pFLL_32(x64emu_t *emu, uintptr_t fnc);
void pEpi_32(x64emu_t *emu, uintptr_t fnc);
void pFpi_32(x64emu_t *emu, uintptr_t fnc);
void pFpu_32(x64emu_t *emu, uintptr_t fnc);
void pFpU_32(x64emu_t *emu, uintptr_t fnc);
void pEpL_32(x64emu_t *emu, uintptr_t fnc);
void pFpL_32(x64emu_t *emu, uintptr_t fnc);
void pEpp_32(x64emu_t *emu, uintptr_t fnc);
void pFpp_32(x64emu_t *emu, uintptr_t fnc);
void pFXi_32(x64emu_t *emu, uintptr_t fnc);
void pFXu_32(x64emu_t *emu, uintptr_t fnc);
void pFXL_32(x64emu_t *emu, uintptr_t fnc);
void pFXp_32(x64emu_t *emu, uintptr_t fnc);
void pFnu_32(x64emu_t *emu, uintptr_t fnc);
void pFnp_32(x64emu_t *emu, uintptr_t fnc);
void hFEp_32(x64emu_t *emu, uintptr_t fnc);
void hEpa_32(x64emu_t *emu, uintptr_t fnc);
void SEip_32(x64emu_t *emu, uintptr_t fnc);
void SEpp_32(x64emu_t *emu, uintptr_t fnc);
void tEip_32(x64emu_t *emu, uintptr_t fnc);
void tEia_32(x64emu_t *emu, uintptr_t fnc);
void tFuu_32(x64emu_t *emu, uintptr_t fnc);
void tEpL_32(x64emu_t *emu, uintptr_t fnc);
void tEpp_32(x64emu_t *emu, uintptr_t fnc);
void vFuBp__32(x64emu_t *emu, uintptr_t fnc);
void vFpbp__32(x64emu_t *emu, uintptr_t fnc);
void vFbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iEEbp__32(x64emu_t *emu, uintptr_t fnc);
void iFibp__32(x64emu_t *emu, uintptr_t fnc);
void iFLbp__32(x64emu_t *emu, uintptr_t fnc);
void iFpbp__32(x64emu_t *emu, uintptr_t fnc);
void iFpbl__32(x64emu_t *emu, uintptr_t fnc);
void iFpBL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbL__32(x64emu_t *emu, uintptr_t fnc);
void iEHBp__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_i_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFXbL__32(x64emu_t *emu, uintptr_t fnc);
void uFubp__32(x64emu_t *emu, uintptr_t fnc);
void uFpbp__32(x64emu_t *emu, uintptr_t fnc);
void uFpbL__32(x64emu_t *emu, uintptr_t fnc);
void fEpBp__32(x64emu_t *emu, uintptr_t fnc);
void dEpBp__32(x64emu_t *emu, uintptr_t fnc);
void dFpbp__32(x64emu_t *emu, uintptr_t fnc);
void lFpbp__32(x64emu_t *emu, uintptr_t fnc);
void LFpbp__32(x64emu_t *emu, uintptr_t fnc);
void LFpbL__32(x64emu_t *emu, uintptr_t fnc);
void pFpbp__32(x64emu_t *emu, uintptr_t fnc);
void pErl_p_32(x64emu_t *emu, uintptr_t fnc);
void vFibpp__32(x64emu_t *emu, uintptr_t fnc);
void vFpbpu__32(x64emu_t *emu, uintptr_t fnc);
void vFBll_l_32(x64emu_t *emu, uintptr_t fnc);
void vFnbpi__32(x64emu_t *emu, uintptr_t fnc);
void iEuBLL__32(x64emu_t *emu, uintptr_t fnc);
void iEurLL__32(x64emu_t *emu, uintptr_t fnc);
void iEprll__32(x64emu_t *emu, uintptr_t fnc);
void iEpbup__32(x64emu_t *emu, uintptr_t fnc);
void iEprLL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu__32(x64emu_t *emu, uintptr_t fnc);
void iFbpi_i_32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iEBll_p_32(x64emu_t *emu, uintptr_t fnc);
void iFXbip__32(x64emu_t *emu, uintptr_t fnc);
void uFpbpu__32(x64emu_t *emu, uintptr_t fnc);
void pFnbpi__32(x64emu_t *emu, uintptr_t fnc);
void vFpbupi__32(x64emu_t *emu, uintptr_t fnc);
void vFbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iEpBlii__32(x64emu_t *emu, uintptr_t fnc);
void iESBliu__32(x64emu_t *emu, uintptr_t fnc);
void iFbppi_i_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iFXbiip__32(x64emu_t *emu, uintptr_t fnc);
void uFpbuup__32(x64emu_t *emu, uintptr_t fnc);
void uFpbuuUp__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuii_p_32(x64emu_t *emu, uintptr_t fnc);
void iErLL_BLL__32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void uFpbuUUUU__32(x64emu_t *emu, uintptr_t fnc);
void uFpbuuupu__32(x64emu_t *emu, uintptr_t fnc);
void pErppppii_p_32(x64emu_t *emu, uintptr_t fnc);
void vFbll_rllll__32(x64emu_t *emu, uintptr_t fnc);
void iEbpppiiip_p_32(x64emu_t *emu, uintptr_t fnc);
void iFXbiiuuLip__32(x64emu_t *emu, uintptr_t fnc);
void iFpruuipWCCp__32(x64emu_t *emu, uintptr_t fnc);
void uFpbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void uFbppuuuuup_p_32(x64emu_t *emu, uintptr_t fnc);
void pFubppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void pFpbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuii_bppuii__32(x64emu_t *emu, uintptr_t fnc);
void lEEriiiiiiiiilt__32(x64emu_t *emu, uintptr_t fnc);
void pEriiiiiiiiilt_p_32(x64emu_t *emu, uintptr_t fnc);
void LFXrLiiwwwwwwwwL__32(x64emu_t *emu, uintptr_t fnc);
void vFpbppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuiiiiiiiiipp_p_32(x64emu_t *emu, uintptr_t fnc);
void uFpbppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuuuuup_bppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void iEiBLLLLLLLLLLLLLLLLLL__32(x64emu_t *emu, uintptr_t fnc);
void iEiBUUUULLLLLLLLLLLLLL__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuiiiiiiiiipp_bppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void uFbppuiiiiiiiiipp_bppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void vEEip_32(x64emu_t *emu, uintptr_t fnc);
void vFEip_32(x64emu_t *emu, uintptr_t fnc);
void vEEpi_32(x64emu_t *emu, uintptr_t fnc);
void vFEpi_32(x64emu_t *emu, uintptr_t fnc);
void vEEpu_32(x64emu_t *emu, uintptr_t fnc);
void vFEpl_32(x64emu_t *emu, uintptr_t fnc);
void vFEpp_32(x64emu_t *emu, uintptr_t fnc);
void vFEpV_32(x64emu_t *emu, uintptr_t fnc);
void vFEXp_32(x64emu_t *emu, uintptr_t fnc);
void vFccc_32(x64emu_t *emu, uintptr_t fnc);
void vFwww_32(x64emu_t *emu, uintptr_t fnc);
void vFiii_32(x64emu_t *emu, uintptr_t fnc);
void vFiif_32(x64emu_t *emu, uintptr_t fnc);
void vFiip_32(x64emu_t *emu, uintptr_t fnc);
void vFiII_32(x64emu_t *emu, uintptr_t fnc);
void vFiui_32(x64emu_t *emu, uintptr_t fnc);
void vFiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFiup_32(x64emu_t *emu, uintptr_t fnc);
void vFiUU_32(x64emu_t *emu, uintptr_t fnc);
void vFiff_32(x64emu_t *emu, uintptr_t fnc);
void vFidd_32(x64emu_t *emu, uintptr_t fnc);
void vFilu_32(x64emu_t *emu, uintptr_t fnc);
void vFill_32(x64emu_t *emu, uintptr_t fnc);
void vFilp_32(x64emu_t *emu, uintptr_t fnc);
void vFipu_32(x64emu_t *emu, uintptr_t fnc);
void vFipp_32(x64emu_t *emu, uintptr_t fnc);
void vFCCC_32(x64emu_t *emu, uintptr_t fnc);
void vFWWW_32(x64emu_t *emu, uintptr_t fnc);
void vFucc_32(x64emu_t *emu, uintptr_t fnc);
void vFuww_32(x64emu_t *emu, uintptr_t fnc);
void vFuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiI_32(x64emu_t *emu, uintptr_t fnc);
void vFuiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiU_32(x64emu_t *emu, uintptr_t fnc);
void vFuif_32(x64emu_t *emu, uintptr_t fnc);
void vFuid_32(x64emu_t *emu, uintptr_t fnc);
void vFuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuII_32(x64emu_t *emu, uintptr_t fnc);
void vFuWW_32(x64emu_t *emu, uintptr_t fnc);
void vFuui_32(x64emu_t *emu, uintptr_t fnc);
void vFuuC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuuf_32(x64emu_t *emu, uintptr_t fnc);
void vFuud_32(x64emu_t *emu, uintptr_t fnc);
void vFuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuUU_32(x64emu_t *emu, uintptr_t fnc);
void vFuff_32(x64emu_t *emu, uintptr_t fnc);
void vFudd_32(x64emu_t *emu, uintptr_t fnc);
void vFull_32(x64emu_t *emu, uintptr_t fnc);
void vFulp_32(x64emu_t *emu, uintptr_t fnc);
void vFupp_32(x64emu_t *emu, uintptr_t fnc);
void vFfff_32(x64emu_t *emu, uintptr_t fnc);
void vEfpp_32(x64emu_t *emu, uintptr_t fnc);
void vFddd_32(x64emu_t *emu, uintptr_t fnc);
void vEdpp_32(x64emu_t *emu, uintptr_t fnc);
void vFlii_32(x64emu_t *emu, uintptr_t fnc);
void vFlip_32(x64emu_t *emu, uintptr_t fnc);
void vFllp_32(x64emu_t *emu, uintptr_t fnc);
void vFlpp_32(x64emu_t *emu, uintptr_t fnc);
void vEpii_32(x64emu_t *emu, uintptr_t fnc);
void vFpii_32(x64emu_t *emu, uintptr_t fnc);
void vFpiL_32(x64emu_t *emu, uintptr_t fnc);
void vFpip_32(x64emu_t *emu, uintptr_t fnc);
void vFpiS_32(x64emu_t *emu, uintptr_t fnc);
void vFpui_32(x64emu_t *emu, uintptr_t fnc);
void vFpuI_32(x64emu_t *emu, uintptr_t fnc);
void vFpuC_32(x64emu_t *emu, uintptr_t fnc);
void vFpuu_32(x64emu_t *emu, uintptr_t fnc);
void vFpuU_32(x64emu_t *emu, uintptr_t fnc);
void vFpuf_32(x64emu_t *emu, uintptr_t fnc);
void vFpud_32(x64emu_t *emu, uintptr_t fnc);
void vFpul_32(x64emu_t *emu, uintptr_t fnc);
void vFpup_32(x64emu_t *emu, uintptr_t fnc);
void vFpdd_32(x64emu_t *emu, uintptr_t fnc);
void vFplp_32(x64emu_t *emu, uintptr_t fnc);
void vFppi_32(x64emu_t *emu, uintptr_t fnc);
void vEppu_32(x64emu_t *emu, uintptr_t fnc);
void vFppu_32(x64emu_t *emu, uintptr_t fnc);
void vFppL_32(x64emu_t *emu, uintptr_t fnc);
void vFppp_32(x64emu_t *emu, uintptr_t fnc);
void vFXiL_32(x64emu_t *emu, uintptr_t fnc);
void vFXLi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLL_32(x64emu_t *emu, uintptr_t fnc);
void vFXLp_32(x64emu_t *emu, uintptr_t fnc);
void vFXpi_32(x64emu_t *emu, uintptr_t fnc);
void vFXpl_32(x64emu_t *emu, uintptr_t fnc);
void vFXpL_32(x64emu_t *emu, uintptr_t fnc);
void vFXpp_32(x64emu_t *emu, uintptr_t fnc);
void iFEip_32(x64emu_t *emu, uintptr_t fnc);
void iEEip_32(x64emu_t *emu, uintptr_t fnc);
void iEEup_32(x64emu_t *emu, uintptr_t fnc);
void iFEup_32(x64emu_t *emu, uintptr_t fnc);
void iEEpi_32(x64emu_t *emu, uintptr_t fnc);
void iFEpi_32(x64emu_t *emu, uintptr_t fnc);
void iFEpu_32(x64emu_t *emu, uintptr_t fnc);
void iFEpl_32(x64emu_t *emu, uintptr_t fnc);
void iEEpL_32(x64emu_t *emu, uintptr_t fnc);
void iFEpL_32(x64emu_t *emu, uintptr_t fnc);
void iEEpp_32(x64emu_t *emu, uintptr_t fnc);
void iFEpp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpV_32(x64emu_t *emu, uintptr_t fnc);
void iFEpX_32(x64emu_t *emu, uintptr_t fnc);
void iEEhi_32(x64emu_t *emu, uintptr_t fnc);
void iEEhp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXp_32(x64emu_t *emu, uintptr_t fnc);
void iEiii_32(x64emu_t *emu, uintptr_t fnc);
void iEiiI_32(x64emu_t *emu, uintptr_t fnc);
void iFiiu_32(x64emu_t *emu, uintptr_t fnc);
void iEiil_32(x64emu_t *emu, uintptr_t fnc);
void iEiip_32(x64emu_t *emu, uintptr_t fnc);
void iFiip_32(x64emu_t *emu, uintptr_t fnc);
void iEiiO_32(x64emu_t *emu, uintptr_t fnc);
void iEiiN_32(x64emu_t *emu, uintptr_t fnc);
void iEiII_32(x64emu_t *emu, uintptr_t fnc);
void iFiui_32(x64emu_t *emu, uintptr_t fnc);
void iEiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFiuL_32(x64emu_t *emu, uintptr_t fnc);
void iEiup_32(x64emu_t *emu, uintptr_t fnc);
void iFiup_32(x64emu_t *emu, uintptr_t fnc);
void iFiUU_32(x64emu_t *emu, uintptr_t fnc);
void iFiUp_32(x64emu_t *emu, uintptr_t fnc);
void iFidd_32(x64emu_t *emu, uintptr_t fnc);
void iEill_32(x64emu_t *emu, uintptr_t fnc);
void iEiLi_32(x64emu_t *emu, uintptr_t fnc);
void iEiLp_32(x64emu_t *emu, uintptr_t fnc);
void iFiLp_32(x64emu_t *emu, uintptr_t fnc);
void iFipi_32(x64emu_t *emu, uintptr_t fnc);
void iEipi_32(x64emu_t *emu, uintptr_t fnc);
void iEipu_32(x64emu_t *emu, uintptr_t fnc);
void iFipu_32(x64emu_t *emu, uintptr_t fnc);
void iEipL_32(x64emu_t *emu, uintptr_t fnc);
void iEipp_32(x64emu_t *emu, uintptr_t fnc);
void iFipp_32(x64emu_t *emu, uintptr_t fnc);
void iEipO_32(x64emu_t *emu, uintptr_t fnc);
void iFuip_32(x64emu_t *emu, uintptr_t fnc);
void iEuui_32(x64emu_t *emu, uintptr_t fnc);
void iEuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFuup_32(x64emu_t *emu, uintptr_t fnc);
void iEuLa_32(x64emu_t *emu, uintptr_t fnc);
void iFupL_32(x64emu_t *emu, uintptr_t fnc);
void iFUip_32(x64emu_t *emu, uintptr_t fnc);
void iFfff_32(x64emu_t *emu, uintptr_t fnc);
void iELLi_32(x64emu_t *emu, uintptr_t fnc);
void iFLpL_32(x64emu_t *emu, uintptr_t fnc);
void iFpii_32(x64emu_t *emu, uintptr_t fnc);
void iEpiu_32(x64emu_t *emu, uintptr_t fnc);
void iFpiu_32(x64emu_t *emu, uintptr_t fnc);
void iFpil_32(x64emu_t *emu, uintptr_t fnc);
void iEpip_32(x64emu_t *emu, uintptr_t fnc);
void iFpip_32(x64emu_t *emu, uintptr_t fnc);
void iFpII_32(x64emu_t *emu, uintptr_t fnc);
void iFpWp_32(x64emu_t *emu, uintptr_t fnc);
void iFpui_32(x64emu_t *emu, uintptr_t fnc);
void iFpuC_32(x64emu_t *emu, uintptr_t fnc);
void iEpuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpuU_32(x64emu_t *emu, uintptr_t fnc);
void iFpup_32(x64emu_t *emu, uintptr_t fnc);
void iFpUU_32(x64emu_t *emu, uintptr_t fnc);
void iFpfu_32(x64emu_t *emu, uintptr_t fnc);
void iFpff_32(x64emu_t *emu, uintptr_t fnc);
void iFpdd_32(x64emu_t *emu, uintptr_t fnc);
void iFpli_32(x64emu_t *emu, uintptr_t fnc);
void iFpll_32(x64emu_t *emu, uintptr_t fnc);
void iEpLi_32(x64emu_t *emu, uintptr_t fnc);
void iEpLu_32(x64emu_t *emu, uintptr_t fnc);
void iEpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpLp_32(x64emu_t *emu, uintptr_t fnc);
void iEppi_32(x64emu_t *emu, uintptr_t fnc);
void iFppi_32(x64emu_t *emu, uintptr_t fnc);
void iFppI_32(x64emu_t *emu, uintptr_t fnc);
void iEppu_32(x64emu_t *emu, uintptr_t fnc);
void iFppu_32(x64emu_t *emu, uintptr_t fnc);
void iFppU_32(x64emu_t *emu, uintptr_t fnc);
void iFppd_32(x64emu_t *emu, uintptr_t fnc);
void iEppL_32(x64emu_t *emu, uintptr_t fnc);
void iFppL_32(x64emu_t *emu, uintptr_t fnc);
void iEppp_32(x64emu_t *emu, uintptr_t fnc);
void iFppp_32(x64emu_t *emu, uintptr_t fnc);
void iEppa_32(x64emu_t *emu, uintptr_t fnc);
void iEpOu_32(x64emu_t *emu, uintptr_t fnc);
void iFpSp_32(x64emu_t *emu, uintptr_t fnc);
void iEhip_32(x64emu_t *emu, uintptr_t fnc);
void iEhpL_32(x64emu_t *emu, uintptr_t fnc);
void iEhpp_32(x64emu_t *emu, uintptr_t fnc);
void iESIi_32(x64emu_t *emu, uintptr_t fnc);
void iESli_32(x64emu_t *emu, uintptr_t fnc);
void iFXii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXip_32(x64emu_t *emu, uintptr_t fnc);
void iFXuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXup_32(x64emu_t *emu, uintptr_t fnc);
void iFXLi_32(x64emu_t *emu, uintptr_t fnc);
void iFXLu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLU_32(x64emu_t *emu, uintptr_t fnc);
void iFXLf_32(x64emu_t *emu, uintptr_t fnc);
void iFXLl_32(x64emu_t *emu, uintptr_t fnc);
void iFXLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLp_32(x64emu_t *emu, uintptr_t fnc);
void iFXpi_32(x64emu_t *emu, uintptr_t fnc);
void iFXpu_32(x64emu_t *emu, uintptr_t fnc);
void iFXpl_32(x64emu_t *emu, uintptr_t fnc);
void iFXpL_32(x64emu_t *emu, uintptr_t fnc);
void iFXpp_32(x64emu_t *emu, uintptr_t fnc);
void IEiIi_32(x64emu_t *emu, uintptr_t fnc);
void IFpIi_32(x64emu_t *emu, uintptr_t fnc);
void IEppi_32(x64emu_t *emu, uintptr_t fnc);
void CFipp_32(x64emu_t *emu, uintptr_t fnc);
void CFuUu_32(x64emu_t *emu, uintptr_t fnc);
void CFuff_32(x64emu_t *emu, uintptr_t fnc);
void WFXip_32(x64emu_t *emu, uintptr_t fnc);
void uFEpW_32(x64emu_t *emu, uintptr_t fnc);
void uFEpu_32(x64emu_t *emu, uintptr_t fnc);
void uFEpU_32(x64emu_t *emu, uintptr_t fnc);
void uFEpL_32(x64emu_t *emu, uintptr_t fnc);
void uFEpp_32(x64emu_t *emu, uintptr_t fnc);
void uFilp_32(x64emu_t *emu, uintptr_t fnc);
void uFipu_32(x64emu_t *emu, uintptr_t fnc);
void uFuuu_32(x64emu_t *emu, uintptr_t fnc);
void uFuup_32(x64emu_t *emu, uintptr_t fnc);
void uFupu_32(x64emu_t *emu, uintptr_t fnc);
void uFupp_32(x64emu_t *emu, uintptr_t fnc);
void uFpii_32(x64emu_t *emu, uintptr_t fnc);
void uFpip_32(x64emu_t *emu, uintptr_t fnc);
void uFpuu_32(x64emu_t *emu, uintptr_t fnc);
void uFpuU_32(x64emu_t *emu, uintptr_t fnc);
void uEpup_32(x64emu_t *emu, uintptr_t fnc);
void uFpup_32(x64emu_t *emu, uintptr_t fnc);
void uFpUp_32(x64emu_t *emu, uintptr_t fnc);
void uFppi_32(x64emu_t *emu, uintptr_t fnc);
void uFppu_32(x64emu_t *emu, uintptr_t fnc);
void uEppL_32(x64emu_t *emu, uintptr_t fnc);
void uFppL_32(x64emu_t *emu, uintptr_t fnc);
void uFppp_32(x64emu_t *emu, uintptr_t fnc);
void uFXuu_32(x64emu_t *emu, uintptr_t fnc);
void UEppi_32(x64emu_t *emu, uintptr_t fnc);
void fFuii_32(x64emu_t *emu, uintptr_t fnc);
void fEfff_32(x64emu_t *emu, uintptr_t fnc);
void fEffp_32(x64emu_t *emu, uintptr_t fnc);
void dEddd_32(x64emu_t *emu, uintptr_t fnc);
void dEddp_32(x64emu_t *emu, uintptr_t fnc);
void lEEuV_32(x64emu_t *emu, uintptr_t fnc);
void lFEpi_32(x64emu_t *emu, uintptr_t fnc);
void lFEpp_32(x64emu_t *emu, uintptr_t fnc);
void lEili_32(x64emu_t *emu, uintptr_t fnc);
void lEipi_32(x64emu_t *emu, uintptr_t fnc);
void lEipL_32(x64emu_t *emu, uintptr_t fnc);
void lFlll_32(x64emu_t *emu, uintptr_t fnc);
void lElpi_32(x64emu_t *emu, uintptr_t fnc);
void lFpLd_32(x64emu_t *emu, uintptr_t fnc);
void lFpLL_32(x64emu_t *emu, uintptr_t fnc);
void lFppi_32(x64emu_t *emu, uintptr_t fnc);
void lFppL_32(x64emu_t *emu, uintptr_t fnc);
void lFppp_32(x64emu_t *emu, uintptr_t fnc);
void LFEpi_32(x64emu_t *emu, uintptr_t fnc);
void LFEpp_32(x64emu_t *emu, uintptr_t fnc);
void LFEXp_32(x64emu_t *emu, uintptr_t fnc);
void LFpii_32(x64emu_t *emu, uintptr_t fnc);
void LEpip_32(x64emu_t *emu, uintptr_t fnc);
void LFppi_32(x64emu_t *emu, uintptr_t fnc);
void LEppL_32(x64emu_t *emu, uintptr_t fnc);
void LFppL_32(x64emu_t *emu, uintptr_t fnc);
void LFXip_32(x64emu_t *emu, uintptr_t fnc);
void LFXCi_32(x64emu_t *emu, uintptr_t fnc);
void LFXLi_32(x64emu_t *emu, uintptr_t fnc);
void LFXLC_32(x64emu_t *emu, uintptr_t fnc);
void LFXpi_32(x64emu_t *emu, uintptr_t fnc);
void LFXpp_32(x64emu_t *emu, uintptr_t fnc);
void pFEii_32(x64emu_t *emu, uintptr_t fnc);
void pFEiu_32(x64emu_t *emu, uintptr_t fnc);
void pEEip_32(x64emu_t *emu, uintptr_t fnc);
void pFEiV_32(x64emu_t *emu, uintptr_t fnc);
void pEEpi_32(x64emu_t *emu, uintptr_t fnc);
void pFEpi_32(x64emu_t *emu, uintptr_t fnc);
void pFEpu_32(x64emu_t *emu, uintptr_t fnc);
void pEEpp_32(x64emu_t *emu, uintptr_t fnc);
void pFEpp_32(x64emu_t *emu, uintptr_t fnc);
void pFEpV_32(x64emu_t *emu, uintptr_t fnc);
void pFEpX_32(x64emu_t *emu, uintptr_t fnc);
void pFEXi_32(x64emu_t *emu, uintptr_t fnc);
void pFEXL_32(x64emu_t *emu, uintptr_t fnc);
void pFEXp_32(x64emu_t *emu, uintptr_t fnc);
void pFiii_32(x64emu_t *emu, uintptr_t fnc);
void pFipp_32(x64emu_t *emu, uintptr_t fnc);
void pFIpi_32(x64emu_t *emu, uintptr_t fnc);
void pFuuu_32(x64emu_t *emu, uintptr_t fnc);
void pFulu_32(x64emu_t *emu, uintptr_t fnc);
void pFupi_32(x64emu_t *emu, uintptr_t fnc);
void pFupL_32(x64emu_t *emu, uintptr_t fnc);
void pFupp_32(x64emu_t *emu, uintptr_t fnc);
void pFUpi_32(x64emu_t *emu, uintptr_t fnc);
void pFddd_32(x64emu_t *emu, uintptr_t fnc);
void pFlpi_32(x64emu_t *emu, uintptr_t fnc);
void pFLpi_32(x64emu_t *emu, uintptr_t fnc);
void pFpcU_32(x64emu_t *emu, uintptr_t fnc);
void pEpii_32(x64emu_t *emu, uintptr_t fnc);
void pFpii_32(x64emu_t *emu, uintptr_t fnc);
void pFpiu_32(x64emu_t *emu, uintptr_t fnc);
void pEpiL_32(x64emu_t *emu, uintptr_t fnc);
void pFpiL_32(x64emu_t *emu, uintptr_t fnc);
void pFpip_32(x64emu_t *emu, uintptr_t fnc);
void pEpiS_32(x64emu_t *emu, uintptr_t fnc);
void pEpII_32(x64emu_t *emu, uintptr_t fnc);
void pFpuu_32(x64emu_t *emu, uintptr_t fnc);
void pFpup_32(x64emu_t *emu, uintptr_t fnc);
void pFpUi_32(x64emu_t *emu, uintptr_t fnc);
void pFpdd_32(x64emu_t *emu, uintptr_t fnc);
void pEpLL_32(x64emu_t *emu, uintptr_t fnc);
void pFppi_32(x64emu_t *emu, uintptr_t fnc);
void pFppu_32(x64emu_t *emu, uintptr_t fnc);
void pEppL_32(x64emu_t *emu, uintptr_t fnc);
void pFppL_32(x64emu_t *emu, uintptr_t fnc);
void pFppp_32(x64emu_t *emu, uintptr_t fnc);
void pFppS_32(x64emu_t *emu, uintptr_t fnc);
void pEpOM_32(x64emu_t *emu, uintptr_t fnc);
void pFXii_32(x64emu_t *emu, uintptr_t fnc);
void pFXip_32(x64emu_t *emu, uintptr_t fnc);
void pFXLp_32(x64emu_t *emu, uintptr_t fnc);
void pFXpi_32(x64emu_t *emu, uintptr_t fnc);
void pFXpp_32(x64emu_t *emu, uintptr_t fnc);
void pFnpL_32(x64emu_t *emu, uintptr_t fnc);
void aEipa_32(x64emu_t *emu, uintptr_t fnc);
void SEEpp_32(x64emu_t *emu, uintptr_t fnc);
void SEppS_32(x64emu_t *emu, uintptr_t fnc);
void tEipu_32(x64emu_t *emu, uintptr_t fnc);
void tEipL_32(x64emu_t *emu, uintptr_t fnc);
void tEppi_32(x64emu_t *emu, uintptr_t fnc);
void vFibp_i_32(x64emu_t *emu, uintptr_t fnc);
void vFuibp__32(x64emu_t *emu, uintptr_t fnc);
void vFuuBp__32(x64emu_t *emu, uintptr_t fnc);
void vFuubp__32(x64emu_t *emu, uintptr_t fnc);
void vFpbp_i_32(x64emu_t *emu, uintptr_t fnc);
void vFbp_pp_32(x64emu_t *emu, uintptr_t fnc);
void vFXLbL__32(x64emu_t *emu, uintptr_t fnc);
void vFXbL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFEpBp__32(x64emu_t *emu, uintptr_t fnc);
void iFWubp__32(x64emu_t *emu, uintptr_t fnc);
void iFuubp__32(x64emu_t *emu, uintptr_t fnc);
void iFUpbp__32(x64emu_t *emu, uintptr_t fnc);
void iFLbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpibl__32(x64emu_t *emu, uintptr_t fnc);
void iFpibp__32(x64emu_t *emu, uintptr_t fnc);
void iFpubp__32(x64emu_t *emu, uintptr_t fnc);
void iFpubL__32(x64emu_t *emu, uintptr_t fnc);
void iFplbl__32(x64emu_t *emu, uintptr_t fnc);
void iEppBp__32(x64emu_t *emu, uintptr_t fnc);
void iFppbp__32(x64emu_t *emu, uintptr_t fnc);
void iFppbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_i_32(x64emu_t *emu, uintptr_t fnc);
void iFpbL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_Wp_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_up_32(x64emu_t *emu, uintptr_t fnc);
void iEBp_LL_32(x64emu_t *emu, uintptr_t fnc);
void iFBp_LL_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pi_32(x64emu_t *emu, uintptr_t fnc);
void iFbL_pi_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pI_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pu_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pd_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pl_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_Si_32(x64emu_t *emu, uintptr_t fnc);
void iFXibL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbp__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbL__32(x64emu_t *emu, uintptr_t fnc);
void iFXbL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXbp_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXBL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFXbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFXbL_p_32(x64emu_t *emu, uintptr_t fnc);
void IEpBp_i_32(x64emu_t *emu, uintptr_t fnc);
void IFpbp_i_32(x64emu_t *emu, uintptr_t fnc);
void uFupbp__32(x64emu_t *emu, uintptr_t fnc);
void uFpubp__32(x64emu_t *emu, uintptr_t fnc);
void uFpubL__32(x64emu_t *emu, uintptr_t fnc);
void uFppbp__32(x64emu_t *emu, uintptr_t fnc);
void uFppbL__32(x64emu_t *emu, uintptr_t fnc);
void uFpbp_p_32(x64emu_t *emu, uintptr_t fnc);
void UEpBp_i_32(x64emu_t *emu, uintptr_t fnc);
void UFpbp_i_32(x64emu_t *emu, uintptr_t fnc);
void fEpBp_p_32(x64emu_t *emu, uintptr_t fnc);
void fEpBp_a_32(x64emu_t *emu, uintptr_t fnc);
void dEpBp_i_32(x64emu_t *emu, uintptr_t fnc);
void dEpBp_a_32(x64emu_t *emu, uintptr_t fnc);
void lEpBp_i_32(x64emu_t *emu, uintptr_t fnc);
void lFpbp_i_32(x64emu_t *emu, uintptr_t fnc);
void lFpbp_L_32(x64emu_t *emu, uintptr_t fnc);
void LEpBp_i_32(x64emu_t *emu, uintptr_t fnc);
void LFpbp_i_32(x64emu_t *emu, uintptr_t fnc);
void pFuXbl__32(x64emu_t *emu, uintptr_t fnc);
void pFpibp__32(x64emu_t *emu, uintptr_t fnc);
void pFpubl__32(x64emu_t *emu, uintptr_t fnc);
void pEppbp__32(x64emu_t *emu, uintptr_t fnc);
void pEppBp__32(x64emu_t *emu, uintptr_t fnc);
void pFppbp__32(x64emu_t *emu, uintptr_t fnc);
void pFXLbL__32(x64emu_t *emu, uintptr_t fnc);
void pFnubp__32(x64emu_t *emu, uintptr_t fnc);
void pFnUbp__32(x64emu_t *emu, uintptr_t fnc);
void vFpibpp__32(x64emu_t *emu, uintptr_t fnc);
void vFpbpu_u_32(x64emu_t *emu, uintptr_t fnc);
void vFpbpu_p_32(x64emu_t *emu, uintptr_t fnc);
void iFLbpi_i_32(x64emu_t *emu, uintptr_t fnc);
void iFpibpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpibpp__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu__32(x64emu_t *emu, uintptr_t fnc);
void iEpprLL__32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_p_32(x64emu_t *emu, uintptr_t fnc);
void iEhprLL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbpp__32(x64emu_t *emu, uintptr_t fnc);
void iFXbLC_i_32(x64emu_t *emu, uintptr_t fnc);
void uFpubpu__32(x64emu_t *emu, uintptr_t fnc);
void vFLbL_bL__32(x64emu_t *emu, uintptr_t fnc);
void vFpbLdd_i_32(x64emu_t *emu, uintptr_t fnc);
void vFpbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iFpbl_bl__32(x64emu_t *emu, uintptr_t fnc);
void iFpbL_bL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pbp__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_bp_p_32(x64emu_t *emu, uintptr_t fnc);
void iEbp_bL_S_32(x64emu_t *emu, uintptr_t fnc);
void iFXbiip_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXbLip_L_32(x64emu_t *emu, uintptr_t fnc);
void vFXLbpLiL__32(x64emu_t *emu, uintptr_t fnc);
void vFXLrpLiL__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_ubpu__32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_pbL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbpLiL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbLLii__32(x64emu_t *emu, uintptr_t fnc);
void uFppbuUuu__32(x64emu_t *emu, uintptr_t fnc);
void vFpbpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFubpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_bpu_u_32(x64emu_t *emu, uintptr_t fnc);
void uFpubuuupu__32(x64emu_t *emu, uintptr_t fnc);
void uFpbpUUuu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFXLbLWWWcc__32(x64emu_t *emu, uintptr_t fnc);
void vFppbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void vFbppuuuuup_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFppbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void uFppbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void LFppbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void pFpibppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void iEirLLLL_BLLLL__32(x64emu_t *emu, uintptr_t fnc);
void pEppriiiiiiiiilt__32(x64emu_t *emu, uintptr_t fnc);
void pFXrLiiwwwwwwwwL_p_32(x64emu_t *emu, uintptr_t fnc);
void vFbppuiiiiiiiiipp_pp_32(x64emu_t *emu, uintptr_t fnc);
void vEEipp_32(x64emu_t *emu, uintptr_t fnc);
void vFEipp_32(x64emu_t *emu, uintptr_t fnc);
void vEEipV_32(x64emu_t *emu, uintptr_t fnc);
void vFEpui_32(x64emu_t *emu, uintptr_t fnc);
void vEEpuu_32(x64emu_t *emu, uintptr_t fnc);
void vEEpup_32(x64emu_t *emu, uintptr_t fnc);
void vFEpup_32(x64emu_t *emu, uintptr_t fnc);
void vFEpll_32(x64emu_t *emu, uintptr_t fnc);
void vFEpLi_32(x64emu_t *emu, uintptr_t fnc);
void vFEppi_32(x64emu_t *emu, uintptr_t fnc);
void vEEppp_32(x64emu_t *emu, uintptr_t fnc);
void vFEppp_32(x64emu_t *emu, uintptr_t fnc);
void vFEXLp_32(x64emu_t *emu, uintptr_t fnc);
void vFEXpi_32(x64emu_t *emu, uintptr_t fnc);
void vFcccc_32(x64emu_t *emu, uintptr_t fnc);
void vFwwww_32(x64emu_t *emu, uintptr_t fnc);
void vFiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFiiCp_32(x64emu_t *emu, uintptr_t fnc);
void vFiill_32(x64emu_t *emu, uintptr_t fnc);
void vFiIII_32(x64emu_t *emu, uintptr_t fnc);
void vFiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFiuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFiulp_32(x64emu_t *emu, uintptr_t fnc);
void vFiupV_32(x64emu_t *emu, uintptr_t fnc);
void vFiUUU_32(x64emu_t *emu, uintptr_t fnc);
void vFifff_32(x64emu_t *emu, uintptr_t fnc);
void vFiddd_32(x64emu_t *emu, uintptr_t fnc);
void vFilip_32(x64emu_t *emu, uintptr_t fnc);
void vFilpu_32(x64emu_t *emu, uintptr_t fnc);
void vFilpp_32(x64emu_t *emu, uintptr_t fnc);
void vFipup_32(x64emu_t *emu, uintptr_t fnc);
void vFipll_32(x64emu_t *emu, uintptr_t fnc);
void vFippp_32(x64emu_t *emu, uintptr_t fnc);
void vFCCCC_32(x64emu_t *emu, uintptr_t fnc);
void vFWWWW_32(x64emu_t *emu, uintptr_t fnc);
void vFuccc_32(x64emu_t *emu, uintptr_t fnc);
void vFuwww_32(x64emu_t *emu, uintptr_t fnc);
void vFuiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiII_32(x64emu_t *emu, uintptr_t fnc);
void vFuiui_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiUU_32(x64emu_t *emu, uintptr_t fnc);
void vFuifi_32(x64emu_t *emu, uintptr_t fnc);
void vFuiff_32(x64emu_t *emu, uintptr_t fnc);
void vFuidd_32(x64emu_t *emu, uintptr_t fnc);
void vFuilp_32(x64emu_t *emu, uintptr_t fnc);
void vFuipu_32(x64emu_t *emu, uintptr_t fnc);
void vFuipp_32(x64emu_t *emu, uintptr_t fnc);
void vFuIII_32(x64emu_t *emu, uintptr_t fnc);
void vFuWWW_32(x64emu_t *emu, uintptr_t fnc);
void vFuuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuil_32(x64emu_t *emu, uintptr_t fnc);
void vFuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuCu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuCp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuui_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuf_32(x64emu_t *emu, uintptr_t fnc);
void vFuuud_32(x64emu_t *emu, uintptr_t fnc);
void vFuuul_32(x64emu_t *emu, uintptr_t fnc);
void vFuuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuUl_32(x64emu_t *emu, uintptr_t fnc);
void vFuuff_32(x64emu_t *emu, uintptr_t fnc);
void vFuuli_32(x64emu_t *emu, uintptr_t fnc);
void vFuupi_32(x64emu_t *emu, uintptr_t fnc);
void vFuupp_32(x64emu_t *emu, uintptr_t fnc);
void vFuUui_32(x64emu_t *emu, uintptr_t fnc);
void vFuUup_32(x64emu_t *emu, uintptr_t fnc);
void vFuUUU_32(x64emu_t *emu, uintptr_t fnc);
void vFufff_32(x64emu_t *emu, uintptr_t fnc);
void vFuddd_32(x64emu_t *emu, uintptr_t fnc);
void vFuluU_32(x64emu_t *emu, uintptr_t fnc);
void vFullC_32(x64emu_t *emu, uintptr_t fnc);
void vFullp_32(x64emu_t *emu, uintptr_t fnc);
void vFulpu_32(x64emu_t *emu, uintptr_t fnc);
void vFulpp_32(x64emu_t *emu, uintptr_t fnc);
void vFupii_32(x64emu_t *emu, uintptr_t fnc);
void vFuppi_32(x64emu_t *emu, uintptr_t fnc);
void vFuppu_32(x64emu_t *emu, uintptr_t fnc);
void vFUUpi_32(x64emu_t *emu, uintptr_t fnc);
void vFffff_32(x64emu_t *emu, uintptr_t fnc);
void vFdddd_32(x64emu_t *emu, uintptr_t fnc);
void vFllii_32(x64emu_t *emu, uintptr_t fnc);
void vFLiii_32(x64emu_t *emu, uintptr_t fnc);
void vFpiip_32(x64emu_t *emu, uintptr_t fnc);
void vFpipi_32(x64emu_t *emu, uintptr_t fnc);
void vFpipp_32(x64emu_t *emu, uintptr_t fnc);
void vFpudd_32(x64emu_t *emu, uintptr_t fnc);
void vFpdii_32(x64emu_t *emu, uintptr_t fnc);
void vFpddd_32(x64emu_t *emu, uintptr_t fnc);
void vFplpp_32(x64emu_t *emu, uintptr_t fnc);
void vFppid_32(x64emu_t *emu, uintptr_t fnc);
void vEppip_32(x64emu_t *emu, uintptr_t fnc);
void vFppui_32(x64emu_t *emu, uintptr_t fnc);
void vFppuu_32(x64emu_t *emu, uintptr_t fnc);
void vFppdd_32(x64emu_t *emu, uintptr_t fnc);
void vFpppp_32(x64emu_t *emu, uintptr_t fnc);
void vFXiiL_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLu_32(x64emu_t *emu, uintptr_t fnc);
void vFXLii_32(x64emu_t *emu, uintptr_t fnc);
void vFXLip_32(x64emu_t *emu, uintptr_t fnc);
void vFXLuu_32(x64emu_t *emu, uintptr_t fnc);
void vFXLLL_32(x64emu_t *emu, uintptr_t fnc);
void vFXLLp_32(x64emu_t *emu, uintptr_t fnc);
void vFXLpi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLpL_32(x64emu_t *emu, uintptr_t fnc);
void vFXpip_32(x64emu_t *emu, uintptr_t fnc);
void vFXppL_32(x64emu_t *emu, uintptr_t fnc);
void cFpiii_32(x64emu_t *emu, uintptr_t fnc);
void iEEiip_32(x64emu_t *emu, uintptr_t fnc);
void iEEiiN_32(x64emu_t *emu, uintptr_t fnc);
void iEEiLp_32(x64emu_t *emu, uintptr_t fnc);
void iEEipp_32(x64emu_t *emu, uintptr_t fnc);
void iFEipp_32(x64emu_t *emu, uintptr_t fnc);
void iEEipV_32(x64emu_t *emu, uintptr_t fnc);
void iEEpii_32(x64emu_t *emu, uintptr_t fnc);
void iEEpip_32(x64emu_t *emu, uintptr_t fnc);
void iFEpip_32(x64emu_t *emu, uintptr_t fnc);
void iFEpui_32(x64emu_t *emu, uintptr_t fnc);
void iFEpuu_32(x64emu_t *emu, uintptr_t fnc);
void iEEpup_32(x64emu_t *emu, uintptr_t fnc);
void iFEpup_32(x64emu_t *emu, uintptr_t fnc);
void iFEpll_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLi_32(x64emu_t *emu, uintptr_t fnc);
void iFEpLi_32(x64emu_t *emu, uintptr_t fnc);
void iEEppi_32(x64emu_t *emu, uintptr_t fnc);
void iFEppi_32(x64emu_t *emu, uintptr_t fnc);
void iFEppu_32(x64emu_t *emu, uintptr_t fnc);
void iEEppL_32(x64emu_t *emu, uintptr_t fnc);
void iEEppp_32(x64emu_t *emu, uintptr_t fnc);
void iFEppp_32(x64emu_t *emu, uintptr_t fnc);
void iEEppV_32(x64emu_t *emu, uintptr_t fnc);
void iFEppV_32(x64emu_t *emu, uintptr_t fnc);
void iEEpON_32(x64emu_t *emu, uintptr_t fnc);
void iEEhup_32(x64emu_t *emu, uintptr_t fnc);
void iEESpp_32(x64emu_t *emu, uintptr_t fnc);
void iEESpV_32(x64emu_t *emu, uintptr_t fnc);
void iFEXip_32(x64emu_t *emu, uintptr_t fnc);
void iFEXup_32(x64emu_t *emu, uintptr_t fnc);
void iFEXlp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpp_32(x64emu_t *emu, uintptr_t fnc);
void iFiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFiiiu_32(x64emu_t *emu, uintptr_t fnc);
void iEiiip_32(x64emu_t *emu, uintptr_t fnc);
void iEiiiN_32(x64emu_t *emu, uintptr_t fnc);
void iEiiII_32(x64emu_t *emu, uintptr_t fnc);
void iEiIIi_32(x64emu_t *emu, uintptr_t fnc);
void iFiuii_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuU_32(x64emu_t *emu, uintptr_t fnc);
void iFiuup_32(x64emu_t *emu, uintptr_t fnc);
void iFiupu_32(x64emu_t *emu, uintptr_t fnc);
void iFiupp_32(x64emu_t *emu, uintptr_t fnc);
void iEilli_32(x64emu_t *emu, uintptr_t fnc);
void iFiLpL_32(x64emu_t *emu, uintptr_t fnc);
void iEipii_32(x64emu_t *emu, uintptr_t fnc);
void iEipip_32(x64emu_t *emu, uintptr_t fnc);
void iEipui_32(x64emu_t *emu, uintptr_t fnc);
void iFipup_32(x64emu_t *emu, uintptr_t fnc);
void iFipLp_32(x64emu_t *emu, uintptr_t fnc);
void iEippi_32(x64emu_t *emu, uintptr_t fnc);
void iFippu_32(x64emu_t *emu, uintptr_t fnc);
void iEippL_32(x64emu_t *emu, uintptr_t fnc);
void iFippL_32(x64emu_t *emu, uintptr_t fnc);
void iFippp_32(x64emu_t *emu, uintptr_t fnc);
void iEipON_32(x64emu_t *emu, uintptr_t fnc);
void iFuiup_32(x64emu_t *emu, uintptr_t fnc);
void iFupLp_32(x64emu_t *emu, uintptr_t fnc);
void iFuppp_32(x64emu_t *emu, uintptr_t fnc);
void iFUpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpiii_32(x64emu_t *emu, uintptr_t fnc);
void iFpiiL_32(x64emu_t *emu, uintptr_t fnc);
void iFpiip_32(x64emu_t *emu, uintptr_t fnc);
void iFpiII_32(x64emu_t *emu, uintptr_t fnc);
void iFpiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpili_32(x64emu_t *emu, uintptr_t fnc);
void iFpipu_32(x64emu_t *emu, uintptr_t fnc);
void iFpipL_32(x64emu_t *emu, uintptr_t fnc);
void iEpipp_32(x64emu_t *emu, uintptr_t fnc);
void iFpipp_32(x64emu_t *emu, uintptr_t fnc);
void iFpCCC_32(x64emu_t *emu, uintptr_t fnc);
void iFpWWu_32(x64emu_t *emu, uintptr_t fnc);
void iEpuiL_32(x64emu_t *emu, uintptr_t fnc);
void iFpuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpuuU_32(x64emu_t *emu, uintptr_t fnc);
void iFpuup_32(x64emu_t *emu, uintptr_t fnc);
void iFpuLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpupi_32(x64emu_t *emu, uintptr_t fnc);
void iFpupu_32(x64emu_t *emu, uintptr_t fnc);
void iFpupL_32(x64emu_t *emu, uintptr_t fnc);
void iFpupp_32(x64emu_t *emu, uintptr_t fnc);
void iFpLuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpLpL_32(x64emu_t *emu, uintptr_t fnc);
void iFpLpp_32(x64emu_t *emu, uintptr_t fnc);
void iFppii_32(x64emu_t *emu, uintptr_t fnc);
void iFppiU_32(x64emu_t *emu, uintptr_t fnc);
void iFppip_32(x64emu_t *emu, uintptr_t fnc);
void iFppWp_32(x64emu_t *emu, uintptr_t fnc);
void iFppuw_32(x64emu_t *emu, uintptr_t fnc);
void iFppui_32(x64emu_t *emu, uintptr_t fnc);
void iFppuu_32(x64emu_t *emu, uintptr_t fnc);
void iFppup_32(x64emu_t *emu, uintptr_t fnc);
void iFppLi_32(x64emu_t *emu, uintptr_t fnc);
void iFppLI_32(x64emu_t *emu, uintptr_t fnc);
void iFppLu_32(x64emu_t *emu, uintptr_t fnc);
void iFppLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpppi_32(x64emu_t *emu, uintptr_t fnc);
void iFpppu_32(x64emu_t *emu, uintptr_t fnc);
void iEpppL_32(x64emu_t *emu, uintptr_t fnc);
void iFpppL_32(x64emu_t *emu, uintptr_t fnc);
void iEpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFpppp_32(x64emu_t *emu, uintptr_t fnc);
void iESpiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXiip_32(x64emu_t *emu, uintptr_t fnc);
void iFXiuL_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXipi_32(x64emu_t *emu, uintptr_t fnc);
void iFXipp_32(x64emu_t *emu, uintptr_t fnc);
void iFXWWW_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuL_32(x64emu_t *emu, uintptr_t fnc);
void iFXuup_32(x64emu_t *emu, uintptr_t fnc);
void iFXuLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXupp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLii_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLip_32(x64emu_t *emu, uintptr_t fnc);
void iFXLuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpi_32(x64emu_t *emu, uintptr_t fnc);
void iFXpii_32(x64emu_t *emu, uintptr_t fnc);
void iFXpip_32(x64emu_t *emu, uintptr_t fnc);
void iFXpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFXppi_32(x64emu_t *emu, uintptr_t fnc);
void iFXppp_32(x64emu_t *emu, uintptr_t fnc);
void IFEpIi_32(x64emu_t *emu, uintptr_t fnc);
void CFuuff_32(x64emu_t *emu, uintptr_t fnc);
void uFEuip_32(x64emu_t *emu, uintptr_t fnc);
void uFEpii_32(x64emu_t *emu, uintptr_t fnc);
void uFEpip_32(x64emu_t *emu, uintptr_t fnc);
void uFEpiV_32(x64emu_t *emu, uintptr_t fnc);
void uFEpup_32(x64emu_t *emu, uintptr_t fnc);
void uFEpLL_32(x64emu_t *emu, uintptr_t fnc);
void uFuuuu_32(x64emu_t *emu, uintptr_t fnc);
void uFuupp_32(x64emu_t *emu, uintptr_t fnc);
void uFupup_32(x64emu_t *emu, uintptr_t fnc);
void uFuppd_32(x64emu_t *emu, uintptr_t fnc);
void uFuppp_32(x64emu_t *emu, uintptr_t fnc);
void uFpiip_32(x64emu_t *emu, uintptr_t fnc);
void uFpCCC_32(x64emu_t *emu, uintptr_t fnc);
void uFpuuu_32(x64emu_t *emu, uintptr_t fnc);
void uFpuup_32(x64emu_t *emu, uintptr_t fnc);
void uFpupu_32(x64emu_t *emu, uintptr_t fnc);
void uFpupp_32(x64emu_t *emu, uintptr_t fnc);
void uFpUpp_32(x64emu_t *emu, uintptr_t fnc);
void uFppii_32(x64emu_t *emu, uintptr_t fnc);
void uFppip_32(x64emu_t *emu, uintptr_t fnc);
void uFppup_32(x64emu_t *emu, uintptr_t fnc);
void uFpppi_32(x64emu_t *emu, uintptr_t fnc);
void uFpppd_32(x64emu_t *emu, uintptr_t fnc);
void uFpppp_32(x64emu_t *emu, uintptr_t fnc);
void lEEipi_32(x64emu_t *emu, uintptr_t fnc);
void lEEipL_32(x64emu_t *emu, uintptr_t fnc);
void lEEppL_32(x64emu_t *emu, uintptr_t fnc);
void lEiipL_32(x64emu_t *emu, uintptr_t fnc);
void lEipLi_32(x64emu_t *emu, uintptr_t fnc);
void lEipLI_32(x64emu_t *emu, uintptr_t fnc);
void lEipLl_32(x64emu_t *emu, uintptr_t fnc);
void lEipLL_32(x64emu_t *emu, uintptr_t fnc);
void lFpuip_32(x64emu_t *emu, uintptr_t fnc);
void lFppLp_32(x64emu_t *emu, uintptr_t fnc);
void LFEpLp_32(x64emu_t *emu, uintptr_t fnc);
void LFEXii_32(x64emu_t *emu, uintptr_t fnc);
void LEpLLS_32(x64emu_t *emu, uintptr_t fnc);
void LEppLL_32(x64emu_t *emu, uintptr_t fnc);
void LEppLp_32(x64emu_t *emu, uintptr_t fnc);
void LEppLa_32(x64emu_t *emu, uintptr_t fnc);
void LFXCii_32(x64emu_t *emu, uintptr_t fnc);
void LFXLuu_32(x64emu_t *emu, uintptr_t fnc);
void LFXpLp_32(x64emu_t *emu, uintptr_t fnc);
void pFEupi_32(x64emu_t *emu, uintptr_t fnc);
void pFEupp_32(x64emu_t *emu, uintptr_t fnc);
void pEEpii_32(x64emu_t *emu, uintptr_t fnc);
void pEEpip_32(x64emu_t *emu, uintptr_t fnc);
void pFEpip_32(x64emu_t *emu, uintptr_t fnc);
void pFEpui_32(x64emu_t *emu, uintptr_t fnc);
void pEEppi_32(x64emu_t *emu, uintptr_t fnc);
void pFEppi_32(x64emu_t *emu, uintptr_t fnc);
void pEEppp_32(x64emu_t *emu, uintptr_t fnc);
void pFEppp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXip_32(x64emu_t *emu, uintptr_t fnc);
void pFEXCL_32(x64emu_t *emu, uintptr_t fnc);
void pFEXuu_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLL_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXpL_32(x64emu_t *emu, uintptr_t fnc);
void pFEXpp_32(x64emu_t *emu, uintptr_t fnc);
void pFiiiu_32(x64emu_t *emu, uintptr_t fnc);
void pFifff_32(x64emu_t *emu, uintptr_t fnc);
void pFillu_32(x64emu_t *emu, uintptr_t fnc);
void pEippu_32(x64emu_t *emu, uintptr_t fnc);
void pFullu_32(x64emu_t *emu, uintptr_t fnc);
void pFdddd_32(x64emu_t *emu, uintptr_t fnc);
void pFpiii_32(x64emu_t *emu, uintptr_t fnc);
void pFpiip_32(x64emu_t *emu, uintptr_t fnc);
void pEpiLL_32(x64emu_t *emu, uintptr_t fnc);
void pFpipc_32(x64emu_t *emu, uintptr_t fnc);
void pFpipi_32(x64emu_t *emu, uintptr_t fnc);
void pFpipp_32(x64emu_t *emu, uintptr_t fnc);
void pFpuii_32(x64emu_t *emu, uintptr_t fnc);
void pFpupu_32(x64emu_t *emu, uintptr_t fnc);
void pFpupp_32(x64emu_t *emu, uintptr_t fnc);
void pEpLiS_32(x64emu_t *emu, uintptr_t fnc);
void pEpLpL_32(x64emu_t *emu, uintptr_t fnc);
void pFpLpL_32(x64emu_t *emu, uintptr_t fnc);
void pEppiL_32(x64emu_t *emu, uintptr_t fnc);
void pFppiS_32(x64emu_t *emu, uintptr_t fnc);
void pEppLL_32(x64emu_t *emu, uintptr_t fnc);
void pFppLp_32(x64emu_t *emu, uintptr_t fnc);
void pFpppi_32(x64emu_t *emu, uintptr_t fnc);
void pFpppL_32(x64emu_t *emu, uintptr_t fnc);
void pFpppp_32(x64emu_t *emu, uintptr_t fnc);
void pFXiii_32(x64emu_t *emu, uintptr_t fnc);
void pFXiip_32(x64emu_t *emu, uintptr_t fnc);
void pFXLpp_32(x64emu_t *emu, uintptr_t fnc);
void pFXppp_32(x64emu_t *emu, uintptr_t fnc);
void vFuibp_i_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuBp__32(x64emu_t *emu, uintptr_t fnc);
void vFbp_ppp_32(x64emu_t *emu, uintptr_t fnc);
void vFXLLbL__32(x64emu_t *emu, uintptr_t fnc);
void iFEpbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpipbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpupbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpubp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFplibl__32(x64emu_t *emu, uintptr_t fnc);
void iFpLpbL__32(x64emu_t *emu, uintptr_t fnc);
void iFppWbp__32(x64emu_t *emu, uintptr_t fnc);
void iFpppbp__32(x64emu_t *emu, uintptr_t fnc);
void iFpppbL__32(x64emu_t *emu, uintptr_t fnc);
void iFppbp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFppbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_ii_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_ip_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_upL_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pii_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pip_32(x64emu_t *emu, uintptr_t fnc);
void iFBp_pui_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_ppu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiBp__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbp_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXLbL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXLbp_p_32(x64emu_t *emu, uintptr_t fnc);
void IEpBp_ii_32(x64emu_t *emu, uintptr_t fnc);
void IEpBp_ia_32(x64emu_t *emu, uintptr_t fnc);
void uFpupbp__32(x64emu_t *emu, uintptr_t fnc);
void uFpubL_u_32(x64emu_t *emu, uintptr_t fnc);
void uFpubp_p_32(x64emu_t *emu, uintptr_t fnc);
void uFppibp__32(x64emu_t *emu, uintptr_t fnc);
void uFppibl__32(x64emu_t *emu, uintptr_t fnc);
void uFppbp_i_32(x64emu_t *emu, uintptr_t fnc);
void uFpbp_ip_32(x64emu_t *emu, uintptr_t fnc);
void UEpBp_ii_32(x64emu_t *emu, uintptr_t fnc);
void UEpBp_ia_32(x64emu_t *emu, uintptr_t fnc);
void lEiibl_L_32(x64emu_t *emu, uintptr_t fnc);
void LEpBp_ii_32(x64emu_t *emu, uintptr_t fnc);
void LEpbp_Lp_32(x64emu_t *emu, uintptr_t fnc);
void pFpppbl__32(x64emu_t *emu, uintptr_t fnc);
void vFpibpp_i_32(x64emu_t *emu, uintptr_t fnc);
void iEEpprLL__32(x64emu_t *emu, uintptr_t fnc);
void iFuubpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpuubpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpupbpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iEpurLL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFppubpu__32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_up_32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_ppp_32(x64emu_t *emu, uintptr_t fnc);
void iFnbpL_iU_32(x64emu_t *emu, uintptr_t fnc);
void lFppLbLL__32(x64emu_t *emu, uintptr_t fnc);
void pFnbpi_up_32(x64emu_t *emu, uintptr_t fnc);
void vFppbp_bL__32(x64emu_t *emu, uintptr_t fnc);
void vFpbLdd_ip_32(x64emu_t *emu, uintptr_t fnc);
void vFpbupu_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFupbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iFppbL_bL__32(x64emu_t *emu, uintptr_t fnc);
void iFppbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iFppbp_bL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbupu_up_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_urp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFrpuu_Lui_32(x64emu_t *emu, uintptr_t fnc);
void iEbp_bL_iS_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_bp_pi_32(x64emu_t *emu, uintptr_t fnc);
void iFXbL_ibp__32(x64emu_t *emu, uintptr_t fnc);
void iFnubp_bp__32(x64emu_t *emu, uintptr_t fnc);
void iFnUbp_bp__32(x64emu_t *emu, uintptr_t fnc);
void vFEpuBLLLL__32(x64emu_t *emu, uintptr_t fnc);
void vFbp_ppbup__32(x64emu_t *emu, uintptr_t fnc);
void vFXLbpLiL_L_32(x64emu_t *emu, uintptr_t fnc);
void iFubpu_pbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_pbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_upbL__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pbpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFXLbpLiL_L_32(x64emu_t *emu, uintptr_t fnc);
void iEiirLL_BLL__32(x64emu_t *emu, uintptr_t fnc);
void iEuirLL_BLL__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_Lbpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_p_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpbLWWWcc__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbLWWWcc_i_32(x64emu_t *emu, uintptr_t fnc);
void uFpbuUuuuu_pU_32(x64emu_t *emu, uintptr_t fnc);
void pESBppppii_pi_32(x64emu_t *emu, uintptr_t fnc);
void iFEprllll_rll__32(x64emu_t *emu, uintptr_t fnc);
void iEupuBpppiiip__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_ubpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFXLuriiiiiLi__32(x64emu_t *emu, uintptr_t fnc);
void uFnibpL_bLpCC__32(x64emu_t *emu, uintptr_t fnc);
void iFppubppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void iFpruuipWCCp_ll_32(x64emu_t *emu, uintptr_t fnc);
void iFpbLL_bLL_bLL__32(x64emu_t *emu, uintptr_t fnc);
void pFppibppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void vFXLbLLLLLLLLLL_L_32(x64emu_t *emu, uintptr_t fnc);
void iFXLbLLLLLLLLLL_L_32(x64emu_t *emu, uintptr_t fnc);
void LEpLpriiiiiiiiilt__32(x64emu_t *emu, uintptr_t fnc);
void iFXipBWWWWWWWWWuip__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbLWWWcc_bLWWWcc__32(x64emu_t *emu, uintptr_t fnc);
void uFEbppuiiiiiiiiipp_ip_32(x64emu_t *emu, uintptr_t fnc);
void uFbppuiiiiiiiiipp_ipi_32(x64emu_t *emu, uintptr_t fnc);
void iFpruuipWCCp_buuipWCCp_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXpLriLLLiiiiiiiLLiiLiiiiLic__32(x64emu_t *emu, uintptr_t fnc);
void iFXpLbiLLLiiiiiiiLLiiLiiiiLic__32(x64emu_t *emu, uintptr_t fnc);
void pFXLLbiLLLiiiiiiiLLiiLiiiiLic__32(x64emu_t *emu, uintptr_t fnc);
void uFbppuiiiiiiiiipp_ipbppuiiiiiiiiipp__32(x64emu_t *emu, uintptr_t fnc);
void vEEiipp_32(x64emu_t *emu, uintptr_t fnc);
void vEEiipV_32(x64emu_t *emu, uintptr_t fnc);
void vFEuipu_32(x64emu_t *emu, uintptr_t fnc);
void vFEuipp_32(x64emu_t *emu, uintptr_t fnc);
void vEEpLLp_32(x64emu_t *emu, uintptr_t fnc);
void vEEppiV_32(x64emu_t *emu, uintptr_t fnc);
void vFEpppp_32(x64emu_t *emu, uintptr_t fnc);
void vFEXLpL_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiu_32(x64emu_t *emu, uintptr_t fnc);
void vFiiuii_32(x64emu_t *emu, uintptr_t fnc);
void vFiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFiillu_32(x64emu_t *emu, uintptr_t fnc);
void vFiilll_32(x64emu_t *emu, uintptr_t fnc);
void vFiipll_32(x64emu_t *emu, uintptr_t fnc);
void vFiIIII_32(x64emu_t *emu, uintptr_t fnc);
void vFiuiip_32(x64emu_t *emu, uintptr_t fnc);
void vFiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFiulpp_32(x64emu_t *emu, uintptr_t fnc);
void vFiUUUU_32(x64emu_t *emu, uintptr_t fnc);
void vFiffff_32(x64emu_t *emu, uintptr_t fnc);
void vFidddd_32(x64emu_t *emu, uintptr_t fnc);
void vFilill_32(x64emu_t *emu, uintptr_t fnc);
void vFilipi_32(x64emu_t *emu, uintptr_t fnc);
void vFilipl_32(x64emu_t *emu, uintptr_t fnc);
void vFipipu_32(x64emu_t *emu, uintptr_t fnc);
void vFipipp_32(x64emu_t *emu, uintptr_t fnc);
void vFipupi_32(x64emu_t *emu, uintptr_t fnc);
void vFucccc_32(x64emu_t *emu, uintptr_t fnc);
void vFuwwww_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiCp_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiill_32(x64emu_t *emu, uintptr_t fnc);
void vFuiIII_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuCi_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuCu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiupi_32(x64emu_t *emu, uintptr_t fnc);
void vFuiUUU_32(x64emu_t *emu, uintptr_t fnc);
void vFuifff_32(x64emu_t *emu, uintptr_t fnc);
void vFuiddd_32(x64emu_t *emu, uintptr_t fnc);
void vFuipii_32(x64emu_t *emu, uintptr_t fnc);
void vFuipip_32(x64emu_t *emu, uintptr_t fnc);
void vFuipup_32(x64emu_t *emu, uintptr_t fnc);
void vFuippp_32(x64emu_t *emu, uintptr_t fnc);
void vFuIIII_32(x64emu_t *emu, uintptr_t fnc);
void vFuCCCC_32(x64emu_t *emu, uintptr_t fnc);
void vFuCuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuCuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuWWWW_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiui_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuifi_32(x64emu_t *emu, uintptr_t fnc);
void vFuuipC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuipu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuipp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuil_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuui_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuli_32(x64emu_t *emu, uintptr_t fnc);
void vFuuull_32(x64emu_t *emu, uintptr_t fnc);
void vFuulll_32(x64emu_t *emu, uintptr_t fnc);
void vFuullp_32(x64emu_t *emu, uintptr_t fnc);
void vFuupii_32(x64emu_t *emu, uintptr_t fnc);
void vFuUUUU_32(x64emu_t *emu, uintptr_t fnc);
void vFuffff_32(x64emu_t *emu, uintptr_t fnc);
void vFudddd_32(x64emu_t *emu, uintptr_t fnc);
void vFullpu_32(x64emu_t *emu, uintptr_t fnc);
void vFupiii_32(x64emu_t *emu, uintptr_t fnc);
void vFupupp_32(x64emu_t *emu, uintptr_t fnc);
void vFuplii_32(x64emu_t *emu, uintptr_t fnc);
void vFuppip_32(x64emu_t *emu, uintptr_t fnc);
void vFupppp_32(x64emu_t *emu, uintptr_t fnc);
void vFfffff_32(x64emu_t *emu, uintptr_t fnc);
void vFddddp_32(x64emu_t *emu, uintptr_t fnc);
void vFluipp_32(x64emu_t *emu, uintptr_t fnc);
void vFpiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFpilpp_32(x64emu_t *emu, uintptr_t fnc);
void vFpipiu_32(x64emu_t *emu, uintptr_t fnc);
void vFpuipp_32(x64emu_t *emu, uintptr_t fnc);
void vFpuddd_32(x64emu_t *emu, uintptr_t fnc);
void vFpddii_32(x64emu_t *emu, uintptr_t fnc);
void vFpdddd_32(x64emu_t *emu, uintptr_t fnc);
void vFppWui_32(x64emu_t *emu, uintptr_t fnc);
void vFpppii_32(x64emu_t *emu, uintptr_t fnc);
void vFppppu_32(x64emu_t *emu, uintptr_t fnc);
void vFppppp_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiii_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiL_32(x64emu_t *emu, uintptr_t fnc);
void vFXLppi_32(x64emu_t *emu, uintptr_t fnc);
void vFXpiiL_32(x64emu_t *emu, uintptr_t fnc);
void iEEiiip_32(x64emu_t *emu, uintptr_t fnc);
void iEEiipV_32(x64emu_t *emu, uintptr_t fnc);
void iEEipii_32(x64emu_t *emu, uintptr_t fnc);
void iEEipuu_32(x64emu_t *emu, uintptr_t fnc);
void iEEipup_32(x64emu_t *emu, uintptr_t fnc);
void iEEippi_32(x64emu_t *emu, uintptr_t fnc);
void iEEippL_32(x64emu_t *emu, uintptr_t fnc);
void iEEuupi_32(x64emu_t *emu, uintptr_t fnc);
void iFEpiup_32(x64emu_t *emu, uintptr_t fnc);
void iEEpipp_32(x64emu_t *emu, uintptr_t fnc);
void iFEpipp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpipV_32(x64emu_t *emu, uintptr_t fnc);
void iFEpuip_32(x64emu_t *emu, uintptr_t fnc);
void iFEpupu_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLpp_32(x64emu_t *emu, uintptr_t fnc);
void iFEpLpp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLpV_32(x64emu_t *emu, uintptr_t fnc);
void iFEpLpV_32(x64emu_t *emu, uintptr_t fnc);
void iEEppii_32(x64emu_t *emu, uintptr_t fnc);
void iFEpplp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpppi_32(x64emu_t *emu, uintptr_t fnc);
void iEEpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFEpppp_32(x64emu_t *emu, uintptr_t fnc);
void iEESipp_32(x64emu_t *emu, uintptr_t fnc);
void iEESipV_32(x64emu_t *emu, uintptr_t fnc);
void iFEXipp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLip_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLlp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLLp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLpi_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLpp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpii_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXppu_32(x64emu_t *emu, uintptr_t fnc);
void iFEXppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiiiui_32(x64emu_t *emu, uintptr_t fnc);
void iEiiipu_32(x64emu_t *emu, uintptr_t fnc);
void iEiiipp_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuU_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuup_32(x64emu_t *emu, uintptr_t fnc);
void iFipiip_32(x64emu_t *emu, uintptr_t fnc);
void iEipLLi_32(x64emu_t *emu, uintptr_t fnc);
void iFippuu_32(x64emu_t *emu, uintptr_t fnc);
void iEippLi_32(x64emu_t *emu, uintptr_t fnc);
void iEipppi_32(x64emu_t *emu, uintptr_t fnc);
void iEipppp_32(x64emu_t *emu, uintptr_t fnc);
void iFuiuup_32(x64emu_t *emu, uintptr_t fnc);
void iFuupid_32(x64emu_t *emu, uintptr_t fnc);
void iFpiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFpiiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpiipp_32(x64emu_t *emu, uintptr_t fnc);
void iFpippL_32(x64emu_t *emu, uintptr_t fnc);
void iFpippp_32(x64emu_t *emu, uintptr_t fnc);
void iFpCCCC_32(x64emu_t *emu, uintptr_t fnc);
void iFpuipp_32(x64emu_t *emu, uintptr_t fnc);
void iFpupuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpupLu_32(x64emu_t *emu, uintptr_t fnc);
void iFpuppp_32(x64emu_t *emu, uintptr_t fnc);
void iFppiUi_32(x64emu_t *emu, uintptr_t fnc);
void iFppipp_32(x64emu_t *emu, uintptr_t fnc);
void iFppWup_32(x64emu_t *emu, uintptr_t fnc);
void iFppuip_32(x64emu_t *emu, uintptr_t fnc);
void iFppupu_32(x64emu_t *emu, uintptr_t fnc);
void iFppLpL_32(x64emu_t *emu, uintptr_t fnc);
void iFppLpp_32(x64emu_t *emu, uintptr_t fnc);
void iFpppip_32(x64emu_t *emu, uintptr_t fnc);
void iFpppuu_32(x64emu_t *emu, uintptr_t fnc);
void iEpppLi_32(x64emu_t *emu, uintptr_t fnc);
void iFpppLu_32(x64emu_t *emu, uintptr_t fnc);
void iEpppLp_32(x64emu_t *emu, uintptr_t fnc);
void iFppppi_32(x64emu_t *emu, uintptr_t fnc);
void iFppppu_32(x64emu_t *emu, uintptr_t fnc);
void iFppppd_32(x64emu_t *emu, uintptr_t fnc);
void iFppppL_32(x64emu_t *emu, uintptr_t fnc);
void iFppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiip_32(x64emu_t *emu, uintptr_t fnc);
void iFXiuLi_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLip_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLii_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpii_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpLi_32(x64emu_t *emu, uintptr_t fnc);
void iFXLppi_32(x64emu_t *emu, uintptr_t fnc);
void iFXpipi_32(x64emu_t *emu, uintptr_t fnc);
void iFXpppp_32(x64emu_t *emu, uintptr_t fnc);
void IFXpIII_32(x64emu_t *emu, uintptr_t fnc);
void uEEippu_32(x64emu_t *emu, uintptr_t fnc);
void uFEpipp_32(x64emu_t *emu, uintptr_t fnc);
void uFEpppp_32(x64emu_t *emu, uintptr_t fnc);
void uFpuuup_32(x64emu_t *emu, uintptr_t fnc);
void uFpuupu_32(x64emu_t *emu, uintptr_t fnc);
void uFpuupp_32(x64emu_t *emu, uintptr_t fnc);
void uFpuppp_32(x64emu_t *emu, uintptr_t fnc);
void uEpLLLS_32(x64emu_t *emu, uintptr_t fnc);
void uFppppp_32(x64emu_t *emu, uintptr_t fnc);
void UFuiCiu_32(x64emu_t *emu, uintptr_t fnc);
void lFpuipC_32(x64emu_t *emu, uintptr_t fnc);
void lFppLpL_32(x64emu_t *emu, uintptr_t fnc);
void LFEppLL_32(x64emu_t *emu, uintptr_t fnc);
void LFEXLpi_32(x64emu_t *emu, uintptr_t fnc);
void LFuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void LEpLppa_32(x64emu_t *emu, uintptr_t fnc);
void LFXLuuu_32(x64emu_t *emu, uintptr_t fnc);
void LFXLpuu_32(x64emu_t *emu, uintptr_t fnc);
void LFXpppi_32(x64emu_t *emu, uintptr_t fnc);
void pFEppip_32(x64emu_t *emu, uintptr_t fnc);
void pFEppdd_32(x64emu_t *emu, uintptr_t fnc);
void pFEpnuu_32(x64emu_t *emu, uintptr_t fnc);
void pFEpnup_32(x64emu_t *emu, uintptr_t fnc);
void pFEXipp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXCip_32(x64emu_t *emu, uintptr_t fnc);
void pFEXlpp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLip_32(x64emu_t *emu, uintptr_t fnc);
void pFEXpip_32(x64emu_t *emu, uintptr_t fnc);
void pFEXppi_32(x64emu_t *emu, uintptr_t fnc);
void pFipipL_32(x64emu_t *emu, uintptr_t fnc);
void pFuiupp_32(x64emu_t *emu, uintptr_t fnc);
void pFpiiii_32(x64emu_t *emu, uintptr_t fnc);
void pFpiiuu_32(x64emu_t *emu, uintptr_t fnc);
void pFpiipi_32(x64emu_t *emu, uintptr_t fnc);
void pFpipii_32(x64emu_t *emu, uintptr_t fnc);
void pFpipip_32(x64emu_t *emu, uintptr_t fnc);
void pFpippi_32(x64emu_t *emu, uintptr_t fnc);
void pFpippp_32(x64emu_t *emu, uintptr_t fnc);
void pFpuiii_32(x64emu_t *emu, uintptr_t fnc);
void pFpuuuu_32(x64emu_t *emu, uintptr_t fnc);
void pFpuppp_32(x64emu_t *emu, uintptr_t fnc);
void pFpdddd_32(x64emu_t *emu, uintptr_t fnc);
void pFpLLip_32(x64emu_t *emu, uintptr_t fnc);
void pFppipi_32(x64emu_t *emu, uintptr_t fnc);
void pFppuup_32(x64emu_t *emu, uintptr_t fnc);
void pFppupp_32(x64emu_t *emu, uintptr_t fnc);
void pFpppii_32(x64emu_t *emu, uintptr_t fnc);
void pFppppi_32(x64emu_t *emu, uintptr_t fnc);
void pFXLipp_32(x64emu_t *emu, uintptr_t fnc);
void pFXpipi_32(x64emu_t *emu, uintptr_t fnc);
void pFXpuup_32(x64emu_t *emu, uintptr_t fnc);
void pFXppip_32(x64emu_t *emu, uintptr_t fnc);
void tEpppLi_32(x64emu_t *emu, uintptr_t fnc);
void vFiuibp_i_32(x64emu_t *emu, uintptr_t fnc);
void vFXibL_ii_32(x64emu_t *emu, uintptr_t fnc);
void iEEBh_ppp_32(x64emu_t *emu, uintptr_t fnc);
void iFpupbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFppibp_I_32(x64emu_t *emu, uintptr_t fnc);
void iFppWpbp__32(x64emu_t *emu, uintptr_t fnc);
void iFppupbL__32(x64emu_t *emu, uintptr_t fnc);
void iFppppbp__32(x64emu_t *emu, uintptr_t fnc);
void iFppbL_pu_32(x64emu_t *emu, uintptr_t fnc);
void iFppbL_pL_32(x64emu_t *emu, uintptr_t fnc);
void iFppbp_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_iii_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_ipi_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_uuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_uup_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_piip_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_puip_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pppi_32(x64emu_t *emu, uintptr_t fnc);
void iFXiibL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXCupbL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbL_ii_32(x64emu_t *emu, uintptr_t fnc);
void uFppbp_ip_32(x64emu_t *emu, uintptr_t fnc);
void LEpbp_LLp_32(x64emu_t *emu, uintptr_t fnc);
void LEpBp_LLp_32(x64emu_t *emu, uintptr_t fnc);
void pFpipibp__32(x64emu_t *emu, uintptr_t fnc);
void pFppupbl__32(x64emu_t *emu, uintptr_t fnc);
void pFppLbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iEippprLL__32(x64emu_t *emu, uintptr_t fnc);
void iFpuibpu_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpupubpu__32(x64emu_t *emu, uintptr_t fnc);
void iEpurLL_pL_32(x64emu_t *emu, uintptr_t fnc);
void iFppubpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFppubpu_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpppibpp__32(x64emu_t *emu, uintptr_t fnc);
void iFppppbup__32(x64emu_t *emu, uintptr_t fnc);
void iFpppbpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_pu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_upu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_upp_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_puu_32(x64emu_t *emu, uintptr_t fnc);
void iFiiuBp_Bp__32(x64emu_t *emu, uintptr_t fnc);
void iFppbp_bp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFbp_bp_pip_32(x64emu_t *emu, uintptr_t fnc);
void vFbp_ppibup__32(x64emu_t *emu, uintptr_t fnc);
void iFEXbpLiL_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFpubp_bpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpppbp_bup__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_pbpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFpibp_bp_bL__32(x64emu_t *emu, uintptr_t fnc);
void iFpuubpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_pbpu__32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_bpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_pu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_bp_u_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiuriiiiiLi__32(x64emu_t *emu, uintptr_t fnc);
void LELbp_bL_bp_bL__32(x64emu_t *emu, uintptr_t fnc);
void LFpbp_bL_bp_bL__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void uFEpbppuuuuup_ip_32(x64emu_t *emu, uintptr_t fnc);
void uFEpbppuuuuup_iV_32(x64emu_t *emu, uintptr_t fnc);
void uFppupbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_bp_bL_bp_bL__32(x64emu_t *emu, uintptr_t fnc);
void vFXLbLLLLLLLLLL_iL_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiiBpLiiiLLLii__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void LEpLpriiiiiiiiilt_a_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLrLiiwwwwwwwwL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpbLWWWcc_bLWWWcc__32(x64emu_t *emu, uintptr_t fnc);
void iFXLpBLWWWcc_BLWWWcc__32(x64emu_t *emu, uintptr_t fnc);
void LFXLrLiiwwwwwwwwL_LriLiiiiLiiiiLi__32(x64emu_t *emu, uintptr_t fnc);
void vFEiiipp_32(x64emu_t *emu, uintptr_t fnc);
void vFEuippp_32(x64emu_t *emu, uintptr_t fnc);
void vFEupupi_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiuil_32(x64emu_t *emu, uintptr_t fnc);
void vFiiilpi_32(x64emu_t *emu, uintptr_t fnc);
void vFiiuilp_32(x64emu_t *emu, uintptr_t fnc);
void vFiffiff_32(x64emu_t *emu, uintptr_t fnc);
void vFiddidd_32(x64emu_t *emu, uintptr_t fnc);
void vFilipli_32(x64emu_t *emu, uintptr_t fnc);
void vFiliplu_32(x64emu_t *emu, uintptr_t fnc);
void vFipiplp_32(x64emu_t *emu, uintptr_t fnc);
void vFCCCCff_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiIIII_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiil_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuCip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiupii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiupiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiUUUU_32(x64emu_t *emu, uintptr_t fnc);
void vFuiffff_32(x64emu_t *emu, uintptr_t fnc);
void vFuidddd_32(x64emu_t *emu, uintptr_t fnc);
void vFuipiup_32(x64emu_t *emu, uintptr_t fnc);
void vFuCuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuil_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuCu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuipC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuipp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuull_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuppi_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuppp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuffff_32(x64emu_t *emu, uintptr_t fnc);
void vFuudddd_32(x64emu_t *emu, uintptr_t fnc);
void vFuupiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuupupp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuplii_32(x64emu_t *emu, uintptr_t fnc);
void vFuffiip_32(x64emu_t *emu, uintptr_t fnc);
void vFufffff_32(x64emu_t *emu, uintptr_t fnc);
void vFuddiip_32(x64emu_t *emu, uintptr_t fnc);
void vFulluUC_32(x64emu_t *emu, uintptr_t fnc);
void vFupiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFdddddd_32(x64emu_t *emu, uintptr_t fnc);
void vFpipipV_32(x64emu_t *emu, uintptr_t fnc);
void vFpudddd_32(x64emu_t *emu, uintptr_t fnc);
void vFpdddii_32(x64emu_t *emu, uintptr_t fnc);
void vFpddddd_32(x64emu_t *emu, uintptr_t fnc);
void vFpppppp_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLppi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiiL_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLpppi_32(x64emu_t *emu, uintptr_t fnc);
void vFXpiiii_32(x64emu_t *emu, uintptr_t fnc);
void iEEiippi_32(x64emu_t *emu, uintptr_t fnc);
void iEEiLLLL_32(x64emu_t *emu, uintptr_t fnc);
void iEEipiup_32(x64emu_t *emu, uintptr_t fnc);
void iEEippup_32(x64emu_t *emu, uintptr_t fnc);
void iEEuppLp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpiipi_32(x64emu_t *emu, uintptr_t fnc);
void iFEpiipi_32(x64emu_t *emu, uintptr_t fnc);
void iEEpiipV_32(x64emu_t *emu, uintptr_t fnc);
void iFEpiuuu_32(x64emu_t *emu, uintptr_t fnc);
void iEEpiLpp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpipOi_32(x64emu_t *emu, uintptr_t fnc);
void iFEpuuip_32(x64emu_t *emu, uintptr_t fnc);
void iFEpuuup_32(x64emu_t *emu, uintptr_t fnc);
void iFEplluu_32(x64emu_t *emu, uintptr_t fnc);
void iFEpLlpp_32(x64emu_t *emu, uintptr_t fnc);
void iFEppipp_32(x64emu_t *emu, uintptr_t fnc);
void iEEppupi_32(x64emu_t *emu, uintptr_t fnc);
void iFEppllp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpppup_32(x64emu_t *emu, uintptr_t fnc);
void iEEpppLp_32(x64emu_t *emu, uintptr_t fnc);
void iFEppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLilp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLpiL_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpiip_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpiup_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuup_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuupu_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuUpU_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiuUuUu_32(x64emu_t *emu, uintptr_t fnc);
void iEipipLu_32(x64emu_t *emu, uintptr_t fnc);
void iFipuIup_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiuup_32(x64emu_t *emu, uintptr_t fnc);
void iFupLpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpiippp_32(x64emu_t *emu, uintptr_t fnc);
void iFppiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFppiipi_32(x64emu_t *emu, uintptr_t fnc);
void iFppipip_32(x64emu_t *emu, uintptr_t fnc);
void iFppippi_32(x64emu_t *emu, uintptr_t fnc);
void iFppuIII_32(x64emu_t *emu, uintptr_t fnc);
void iFppulll_32(x64emu_t *emu, uintptr_t fnc);
void iFpppuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpppupu_32(x64emu_t *emu, uintptr_t fnc);
void iFpppppL_32(x64emu_t *emu, uintptr_t fnc);
void iFpppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFpppppS_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiLip_32(x64emu_t *emu, uintptr_t fnc);
void iFXiippp_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiiiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiiip_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLuupp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLupip_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLLLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLppii_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXpIppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXpuiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXpLiWL_32(x64emu_t *emu, uintptr_t fnc);
void iFXpLLiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXppppi_32(x64emu_t *emu, uintptr_t fnc);
void uFEpippi_32(x64emu_t *emu, uintptr_t fnc);
void uFupuufp_32(x64emu_t *emu, uintptr_t fnc);
void uFpppppp_32(x64emu_t *emu, uintptr_t fnc);
void lEipLipu_32(x64emu_t *emu, uintptr_t fnc);
void lEipLipp_32(x64emu_t *emu, uintptr_t fnc);
void pFEpiiuu_32(x64emu_t *emu, uintptr_t fnc);
void pEEpLLiN_32(x64emu_t *emu, uintptr_t fnc);
void pEEppLLp_32(x64emu_t *emu, uintptr_t fnc);
void pFEpnCWp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLLLp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLpii_32(x64emu_t *emu, uintptr_t fnc);
void pFEXpppp_32(x64emu_t *emu, uintptr_t fnc);
void pFWCiWCi_32(x64emu_t *emu, uintptr_t fnc);
void pFdddddd_32(x64emu_t *emu, uintptr_t fnc);
void pFLppppp_32(x64emu_t *emu, uintptr_t fnc);
void pFpiiiiu_32(x64emu_t *emu, uintptr_t fnc);
void pFpiipip_32(x64emu_t *emu, uintptr_t fnc);
void pFpiippp_32(x64emu_t *emu, uintptr_t fnc);
void pFpipipL_32(x64emu_t *emu, uintptr_t fnc);
void pFpipipp_32(x64emu_t *emu, uintptr_t fnc);
void pFpipuii_32(x64emu_t *emu, uintptr_t fnc);
void pFpuuupu_32(x64emu_t *emu, uintptr_t fnc);
void pFppiiii_32(x64emu_t *emu, uintptr_t fnc);
void XFpppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFpupupbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpupbL_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFppuupbL__32(x64emu_t *emu, uintptr_t fnc);
void iFppupbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpppibp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpppppbp__32(x64emu_t *emu, uintptr_t fnc);
void iFpppbp_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_iuii_32(x64emu_t *emu, uintptr_t fnc);
void iFXibL_ppu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiiibL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLLLLbL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbL_ipi_32(x64emu_t *emu, uintptr_t fnc);
void iFXbL_upip_32(x64emu_t *emu, uintptr_t fnc);
void pFEppibp_p_32(x64emu_t *emu, uintptr_t fnc);
void pEEppbL_Lp_32(x64emu_t *emu, uintptr_t fnc);
void iEEipuurLL__32(x64emu_t *emu, uintptr_t fnc);
void iEippprLL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFupupLbpu__32(x64emu_t *emu, uintptr_t fnc);
void iFppppibpp__32(x64emu_t *emu, uintptr_t fnc);
void iFpppbpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_uppu_32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_pLpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpuuubupu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFppbL_pbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFppbp_pbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpibp_pibpp__32(x64emu_t *emu, uintptr_t fnc);
void iFpuubpu_pbL__32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_puupbL__32(x64emu_t *emu, uintptr_t fnc);
void iFpppbp_bp_bL__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_uuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_upu_32(x64emu_t *emu, uintptr_t fnc);
void iFpbp_bp_bp_ii_32(x64emu_t *emu, uintptr_t fnc);
void iFrpuu_Lrpuu_Lui_32(x64emu_t *emu, uintptr_t fnc);
void iFXbLip_uubLip_L_32(x64emu_t *emu, uintptr_t fnc);
void uFnibpL_bLpCC_up_32(x64emu_t *emu, uintptr_t fnc);
void vFbp_bppup_ippbp__32(x64emu_t *emu, uintptr_t fnc);
void iFpupbpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_bpu_bpu_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_bpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void uFEppppbppuuuuup__32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFppbpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void vFEuuippp_32(x64emu_t *emu, uintptr_t fnc);
void vFEupupip_32(x64emu_t *emu, uintptr_t fnc);
void vFEppupui_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFiiuilil_32(x64emu_t *emu, uintptr_t fnc);
void vFiiffffp_32(x64emu_t *emu, uintptr_t fnc);
void vFiuulipi_32(x64emu_t *emu, uintptr_t fnc);
void vFiupuuup_32(x64emu_t *emu, uintptr_t fnc);
void vFilipliu_32(x64emu_t *emu, uintptr_t fnc);
void vFilulipi_32(x64emu_t *emu, uintptr_t fnc);
void vFCCCCfff_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuCiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiupiiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuiupuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuipiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuipffff_32(x64emu_t *emu, uintptr_t fnc);
void vFuipdddd_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiCiui_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiCiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuipppp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiiCp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiuil_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiupi_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuulll_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuffff_32(x64emu_t *emu, uintptr_t fnc);
void vFuuudddd_32(x64emu_t *emu, uintptr_t fnc);
void vFuuffiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuddiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuulluup_32(x64emu_t *emu, uintptr_t fnc);
void vFuupiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuppppp_32(x64emu_t *emu, uintptr_t fnc);
void vFuffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFudddddd_32(x64emu_t *emu, uintptr_t fnc);
void vFlliiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFpipipiu_32(x64emu_t *emu, uintptr_t fnc);
void vFpddiidd_32(x64emu_t *emu, uintptr_t fnc);
void vFpdddddd_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiiLi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiuui_32(x64emu_t *emu, uintptr_t fnc);
void vFXLLuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFXLppipi_32(x64emu_t *emu, uintptr_t fnc);
void vFXpiipii_32(x64emu_t *emu, uintptr_t fnc);
void vFXppiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFElppppp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLiipp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLiipV_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLiLpV_32(x64emu_t *emu, uintptr_t fnc);
void iFEpppipp_32(x64emu_t *emu, uintptr_t fnc);
void iFEpppupp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLpiiL_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuuii_32(x64emu_t *emu, uintptr_t fnc);
void iFippuIup_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void iFpiuuuiu_32(x64emu_t *emu, uintptr_t fnc);
void iFpWCiWCi_32(x64emu_t *emu, uintptr_t fnc);
void iEpupupui_32(x64emu_t *emu, uintptr_t fnc);
void iFpLpLpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFpLppiip_32(x64emu_t *emu, uintptr_t fnc);
void iFppupipi_32(x64emu_t *emu, uintptr_t fnc);
void iFXiuLiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLuupp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiiiiL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiiuui_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpiiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpiiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpiipi_32(x64emu_t *emu, uintptr_t fnc);
void iFXLppiii_32(x64emu_t *emu, uintptr_t fnc);
void iFXpiipii_32(x64emu_t *emu, uintptr_t fnc);
void iFXpLiWwL_32(x64emu_t *emu, uintptr_t fnc);
void iFXpLuuii_32(x64emu_t *emu, uintptr_t fnc);
void uFEpppppp_32(x64emu_t *emu, uintptr_t fnc);
void uFuippppp_32(x64emu_t *emu, uintptr_t fnc);
void uFpippppp_32(x64emu_t *emu, uintptr_t fnc);
void uFpuupppp_32(x64emu_t *emu, uintptr_t fnc);
void uFppppppp_32(x64emu_t *emu, uintptr_t fnc);
void lEEipLpLL_32(x64emu_t *emu, uintptr_t fnc);
void pFEpiiiiu_32(x64emu_t *emu, uintptr_t fnc);
void pFEpLiiii_32(x64emu_t *emu, uintptr_t fnc);
void pEEpLiiiI_32(x64emu_t *emu, uintptr_t fnc);
void pFEpLiiiI_32(x64emu_t *emu, uintptr_t fnc);
void pEEpLiiil_32(x64emu_t *emu, uintptr_t fnc);
void pFEpXppip_32(x64emu_t *emu, uintptr_t fnc);
void pFpipiupp_32(x64emu_t *emu, uintptr_t fnc);
void pFpuuupuu_32(x64emu_t *emu, uintptr_t fnc);
void pFppppiii_32(x64emu_t *emu, uintptr_t fnc);
void vFXLLiiibl__32(x64emu_t *emu, uintptr_t fnc);
void iFppppppbp__32(x64emu_t *emu, uintptr_t fnc);
void pFpiipipbp__32(x64emu_t *emu, uintptr_t fnc);
void iFppppubpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLibiip_ip_32(x64emu_t *emu, uintptr_t fnc);
void iFXLibL_ubL_u_32(x64emu_t *emu, uintptr_t fnc);
void iFppibp_pibpp__32(x64emu_t *emu, uintptr_t fnc);
void iFXLpiibpiiL_i_32(x64emu_t *emu, uintptr_t fnc);
void iFppbupu_uubpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFppubpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void LFXLLuubLWWWcc_bLWWWcc__32(x64emu_t *emu, uintptr_t fnc);
void LFXLLbLWWWcc_bLWWWcc_uu_32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_bpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_bpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void vFEXLpiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFiilliilp_32(x64emu_t *emu, uintptr_t fnc);
void vFiupuiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFiupuuuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiipiup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiCuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuCCCCfff_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiuupp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiiiiu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiuCil_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuipipp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuufffff_32(x64emu_t *emu, uintptr_t fnc);
void vFffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLpiiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiiLii_32(x64emu_t *emu, uintptr_t fnc);
void vFXLLLiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFXppuulll_32(x64emu_t *emu, uintptr_t fnc);
void iFEpippupp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpippppp_32(x64emu_t *emu, uintptr_t fnc);
void iEEpLiLppp_32(x64emu_t *emu, uintptr_t fnc);
void iFEppipppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiipppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuCCuup_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuupip_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void iFupipppip_32(x64emu_t *emu, uintptr_t fnc);
void iFpuuiiuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFpLpiLpLp_32(x64emu_t *emu, uintptr_t fnc);
void iFXuupuupp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpipppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLppLpip_32(x64emu_t *emu, uintptr_t fnc);
void iFXpIIIppp_32(x64emu_t *emu, uintptr_t fnc);
void CFuiifpppp_32(x64emu_t *emu, uintptr_t fnc);
void uFuipppppp_32(x64emu_t *emu, uintptr_t fnc);
void uFuupuuiuf_32(x64emu_t *emu, uintptr_t fnc);
void uFulpppppp_32(x64emu_t *emu, uintptr_t fnc);
void LFEXLppuuu_32(x64emu_t *emu, uintptr_t fnc);
void LFXLpuuLLu_32(x64emu_t *emu, uintptr_t fnc);
void pFEppipipp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXpLLppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLiippBL__32(x64emu_t *emu, uintptr_t fnc);
void iFXLpppbL_pp_32(x64emu_t *emu, uintptr_t fnc);
void pFpuuuuupbp__32(x64emu_t *emu, uintptr_t fnc);
void iFppppubpu_Iu_32(x64emu_t *emu, uintptr_t fnc);
void iFpppbpu_ppuu_32(x64emu_t *emu, uintptr_t fnc);
void vFppibLdd_ipiu_32(x64emu_t *emu, uintptr_t fnc);
void iFpupbL_ppbL_p_32(x64emu_t *emu, uintptr_t fnc);
void iFpppibp_pbp_p_32(x64emu_t *emu, uintptr_t fnc);
void iFbpu_upppppbp__32(x64emu_t *emu, uintptr_t fnc);
void iFbp_ubp_ubp_uup_32(x64emu_t *emu, uintptr_t fnc);
void iFpubpu_bpu_bpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void vFEXLppiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiiiill_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiillli_32(x64emu_t *emu, uintptr_t fnc);
void vFiiilllilp_32(x64emu_t *emu, uintptr_t fnc);
void vFiupuiuuup_32(x64emu_t *emu, uintptr_t fnc);
void vFiupuuuuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiCuU_32(x64emu_t *emu, uintptr_t fnc);
void vFuiupuffup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiiC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuiiiiCp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuupuuiuuf_32(x64emu_t *emu, uintptr_t fnc);
void vFuffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFffCCCCfff_32(x64emu_t *emu, uintptr_t fnc);
void vFddddddddd_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLpiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFXLiiipiii_32(x64emu_t *emu, uintptr_t fnc);
void iFEpuippupp_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLLLiipi_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuppppu_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiuuiiip_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiupiiup_32(x64emu_t *emu, uintptr_t fnc);
void iFdddpppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuuLiiip_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuuLpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLiuiiLLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLiiuuii_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpiiuuii_32(x64emu_t *emu, uintptr_t fnc);
void uFuulpiuiuf_32(x64emu_t *emu, uintptr_t fnc);
void LFXLiiiiiip_32(x64emu_t *emu, uintptr_t fnc);
void LFXLiiuuuLL_32(x64emu_t *emu, uintptr_t fnc);
void pFEuiiiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void pFEpnCuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLiiuuLi_32(x64emu_t *emu, uintptr_t fnc);
void pFpiiiiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void pFppupppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLbL_pppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLiiibiip_ip_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLLLiiibiip__32(x64emu_t *emu, uintptr_t fnc);
void iFXLbL_bL_ppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFuuppuubpu_bpu_u_32(x64emu_t *emu, uintptr_t fnc);
void iFpuuuuuubpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void iFpuupbpu_ubpu_uu_32(x64emu_t *emu, uintptr_t fnc);
void pFEXbpLiLLLii_uippuu_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLrLiiwwwwwwwwL_iipi_32(x64emu_t *emu, uintptr_t fnc);
void iFpbpu_bpu_bpu_bpu_bpu_bpu_bpu_bpu__32(x64emu_t *emu, uintptr_t fnc);
void vFEXLpppippp_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiiiiiui_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiiiiiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFiiillliiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiuiiiiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuuCCC_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuupuiupuuf_32(x64emu_t *emu, uintptr_t fnc);
void vFuffiiffiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuddiiddiip_32(x64emu_t *emu, uintptr_t fnc);
void vFffffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFppipipippi_32(x64emu_t *emu, uintptr_t fnc);
void iFEppippippp_32(x64emu_t *emu, uintptr_t fnc);
void iFEppppppppu_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpLiipiiL_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuupppppu_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiiuuiiip_32(x64emu_t *emu, uintptr_t fnc);
void iFppuuiiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLLdduudd_32(x64emu_t *emu, uintptr_t fnc);
void iFXuuLiuiiLL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLpiiuuii_32(x64emu_t *emu, uintptr_t fnc);
void pFEpiiiiuuuu_32(x64emu_t *emu, uintptr_t fnc);
void pFEpnCuuuCup_32(x64emu_t *emu, uintptr_t fnc);
void pFXpuiipuuii_32(x64emu_t *emu, uintptr_t fnc);
void iFppLpLLpLpbL__32(x64emu_t *emu, uintptr_t fnc);
void iFXiiLiiibiip_ip_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLLiiibiip_ip_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiillliip_32(x64emu_t *emu, uintptr_t fnc);
void vFiiiiilllilp_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiillliip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiuiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuupupppppp_32(x64emu_t *emu, uintptr_t fnc);
void vFuuffiiffiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuufffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFuuddiiddiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuUuuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuffffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFUufffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFpiiiiiiiiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFpipipiipiiu_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLppiiiiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFEXpLLiiLWpi_32(x64emu_t *emu, uintptr_t fnc);
void iFuiiiiuuiiip_32(x64emu_t *emu, uintptr_t fnc);
void iFuppipipippi_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLpiiuuiiL_32(x64emu_t *emu, uintptr_t fnc);
void pFEXpuiipuuii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiiLLiiibiip_ip_32(x64emu_t *emu, uintptr_t fnc);
void iFXLibL_iiiibL_bL_bL__32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLrLiiwwwwwwwwL_iiiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiiuUC_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiuuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiiiiuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiiiuip_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFffffffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLpiiiipii_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLppiiiiuui_32(x64emu_t *emu, uintptr_t fnc);
void iFpLpuuLpLpppL_32(x64emu_t *emu, uintptr_t fnc);
void iFXLpppppppppp_32(x64emu_t *emu, uintptr_t fnc);
void pFEXLiiuuLipii_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLbL_bL_ppppbip_pp_32(x64emu_t *emu, uintptr_t fnc);
void iFXiLlliLBL_pBL_BL_bp__32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLrLiiwwwwwwwwL_Liiiipi_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiiiiiuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuuuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuUuuuuuuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void vFuffffffffffff_32(x64emu_t *emu, uintptr_t fnc);
void vFXiLLLiiiiiiuu_32(x64emu_t *emu, uintptr_t fnc);
void iFEXLLlliLppppp_32(x64emu_t *emu, uintptr_t fnc);
void iFiuuuuiiuuuuuu_32(x64emu_t *emu, uintptr_t fnc);
void iFddddpppddpppp_32(x64emu_t *emu, uintptr_t fnc);
void iFXippuuuiipppp_32(x64emu_t *emu, uintptr_t fnc);
void uFippuuuulllipp_32(x64emu_t *emu, uintptr_t fnc);
void LFEXLiiuuuiupLp_32(x64emu_t *emu, uintptr_t fnc);
void iFXLLlliiLBL_pBL_BL_Bp__32(x64emu_t *emu, uintptr_t fnc);
void vFuffiiffiiffiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuddiiddiiddiip_32(x64emu_t *emu, uintptr_t fnc);
void vFuiiiiiuiiiiilll_32(x64emu_t *emu, uintptr_t fnc);
void vFuuiiiiuuiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFfffffffffffffff_32(x64emu_t *emu, uintptr_t fnc);
void iFpppppppppppppppp_32(x64emu_t *emu, uintptr_t fnc);
void pFEppnCuuwwWWWWuup_32(x64emu_t *emu, uintptr_t fnc);
void vFuuuuiiiiuuiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void vFXpuiiiiipuiiiiiiii_32(x64emu_t *emu, uintptr_t fnc);
void uFippuuuuiiiiuuiiiiiiiipp_32(x64emu_t *emu, uintptr_t fnc);

#if defined(HAVE_LD80BITS)
void DED_32(x64emu_t *emu, uintptr_t fnc);
void DFDi_32(x64emu_t *emu, uintptr_t fnc);
void DEDi_32(x64emu_t *emu, uintptr_t fnc);
void DEDD_32(x64emu_t *emu, uintptr_t fnc);
void DFDp_32(x64emu_t *emu, uintptr_t fnc);
void DEDp_32(x64emu_t *emu, uintptr_t fnc);
void DEpBp_a_32(x64emu_t *emu, uintptr_t fnc);
#endif

#if !defined(HAVE_LD80BITS)
void KEK_32(x64emu_t *emu, uintptr_t fnc);
void KFKi_32(x64emu_t *emu, uintptr_t fnc);
void KEKi_32(x64emu_t *emu, uintptr_t fnc);
void KEKK_32(x64emu_t *emu, uintptr_t fnc);
void KFKp_32(x64emu_t *emu, uintptr_t fnc);
void KEKp_32(x64emu_t *emu, uintptr_t fnc);
void KEpBp_a_32(x64emu_t *emu, uintptr_t fnc);
#endif

#if defined(WINLATOR_GLIBC)
void pEipi_32(x64emu_t *emu, uintptr_t fnc);
#endif

#if !defined(WINLATOR_GLIBC)
void pEEipi_32(x64emu_t *emu, uintptr_t fnc);
#endif

void UEsvvs_32(x64emu_t *emu, uintptr_t fnc);
#endif // __WRAPPER32_H_
